@@ -7,7 +7,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
 	minplotnum.strat=2, na.rm=TRUE, removeifnostrata=FALSE, 
  	auxtext="auxlut", removetext="unitarea",
 	pvars2keep=NULL, standardize=TRUE, AOI=FALSE, 
-	keepadjvars=FALSE, adjvars=NULL){
+	keepadjvars=FALSE, adjvars=NULL) {
 
   ##################################################################################
   ## DESCRIPTION:
@@ -37,28 +37,29 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   ##	 	unit.action='combine'
   ## If module = GB,PB, and getwt=TRUE, calculate strat weights (i.e., proportions)
   ##################################################################################
-
+  
   ## Set global variables
   ONEUNIT=npixels=nonsampplots=strvars=PLOT_STATUS_CD=strwt=testlt1=
-		pixels=unitstrgrplut=vars2combine=STRATASUB=unitlessthan=errtyp <- NULL
+    pixels=unitstrgrplut=vars2combine=unitlessthan=errtyp <- NULL
   gui=pivotstrat <- FALSE
   unitvars <- c(unitvar2, unitvar)
   strunitvars <- c(unitvars)
-
+  stratalevels <- NULL
+  
   ## Check auxlut
   #stopifnull <- ifelse((module == "SA" || (module == "MA" && any(MAmethod != "HT"))),
-#				TRUE, FALSE)
+  #				TRUE, FALSE)
   auxlut <- pcheck.table(auxlut, gui=gui, tabnm="auxlut",
- 		             caption="Strata table?", nullcheck=TRUE)
+                         caption="Strata table?", nullcheck=TRUE)
   P2POINTCNT <- pcheck.table(P2POINTCNT)
-
+  
   ## Subset auxiliary data to AOI = 1
   if (AOI && "AOI" %in% names(auxlut)) {
     auxlut <- auxlut[auxlut$AOI == 1, ]
-	
-	  if (!is.null(unitarea)) {
-	    unitarea <- unitarea[unitarea[[unitvar]] %in% auxlut[[unitvar]], ]
-	  }
+    
+    if (!is.null(unitarea)) {
+      unitarea <- unitarea[unitarea[[unitvar]] %in% auxlut[[unitvar]], ]
+    }
   }
 
   #######################################################################
@@ -67,131 +68,23 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   if (strata && module != "SA") {
     auxnmlst <- names(auxlut)
     strvar <- pcheck.varchar(var2check=strvar, varnm="strvar",
-		gui=gui, checklst=c("NONE", names(auxlut)), caption="Strata variable?",
-		warn="strata variable not in stratalut", stopifnull=TRUE)
+                             gui=gui, checklst=c("NONE", names(auxlut)), caption="Strata variable?",
+                             warn="strata variable not in stratalut", stopifnull=TRUE)
     strvars <- strvar
-
+    
     ## Check for a total value in the last row of table..  If exists, exclude.
     lastrow <- auxlut[nrow(auxlut),]
     if (length(grep("Total", lastrow, ignore.case=TRUE)) > 0) {
       auxlut <- auxlut[-nrow(auxlut)]
     }
-	
-	  ## Make strvar a factor for retaining order for collapsing
-	  if (!is.factor(auxlut[[strvar]])) {
-	    auxlut[[strvar]] <- factor(auxlut[[strvar]])
-	  }
- 
+    
+    ## Make strvar a factor for retaining order for collapsing
+#    if (!is.factor(auxlut[[strvar]])) {
+#      auxlut[[strvar]] <- factor(auxlut[[strvar]])
+#    }
+    
     ## If auxlut is NULL, generate based on unitvars in pltx
     #############################################################
-    if (is.null(auxlut)) {
-      auxlut <- unique(pltx[, c(unitvar2, unitvar), with=FALSE])
-    } else {
-      if (any(grepl("ONEUNIT", unitvars))) {
-        unittest <- unitvars[any(grepl("ONEUNIT", unitvars))]
-        if (length(unittest) > 1) {
-            stop("more than one ONEUNIT variable")
-        }
-        if (!unittest %in% names(auxlut)) {
-            auxlut[, (unittest) := 1]
-        }
-      }
-    }
-    ## Keep adjustment variables in auxlut (i.e., from FIADB)
-    if (keepadjvars && !is.null(adjvars)) {
-	    adjvars <- adjvars[adjvars %in% names(auxlut)]
-	    if (length(adjvars) > 0) {
-	      auxlutadj <- auxlut[, c(unitvars, strvars, adjvars), with=FALSE]
-	    } else {
-	      keepadjvars <- FALSE
-	    }
-	  }
-
-    ## Define sumvars to aggregate
-    sumvars <- c(getwtvar, strwtvar, npixelvar)
-
-    ## Aggregate strata by estimation unit to make sure no duplicate values exist
-    sumvars <- unique(sumvars[sumvars %in% names(auxlut)])
-    if (length(sumvars) > 0) {
-      auxlut[, (sumvars) := lapply(.SD, as.numeric), .SDcols=sumvars]
-      auxlut <- auxlut[, lapply(.SD, sum, na.rm=TRUE),
-				by=c(unitvars, strvars), .SDcols=sumvars]
-      setnames(auxlut, c(unitvars, strvars, sumvars))
-
-      auxlut <- auxlut[, lapply(.SD, sum, na.rm=TRUE),
-				by=c(unitvars, strvars), .SDcols=sumvars]
-      setnames(auxlut, c(unitvars, strvars, sumvars))
-    }
-	
-    #setkeyv(auxlut, unitvars)
-    strunitvars <- c(unitvars, strvars)
-
-	  if (keepadjvars && nrow(auxlut) == nrow(auxlutadj)) {
-	    auxlut <- merge(auxlut, auxlutadj, by=strunitvars)
-	  }  
-	
-    ## Check if class of unitvar in auxlut matches class of unitvar in pltx
-    tabs <- check.matchclass(pltx, auxlut, c(unitvars, strvars),
-		                  tab1txt="pltassgn", tab2txt="auxlut")
-    pltx <- tabs$tab1
-    auxlut <- tabs$tab2
-
-    ## Check that the strunitvars in pltx are all in auxlut
-    pltx <- check.matchval(tab1=pltx, tab2=auxlut, var1=c(unitvars, strvars),
-		tab1txt="plt", tab2txt=auxtext, stopifmiss=FALSE, subsetrows=TRUE)
-
-    ## Check that the strunitvars in pltx are all in auxlut
-    pltx <- check.matchval(tab1=pltx, tab2=auxlut, var1=c(unitvars, strvars),
-		tab1txt="plt", tab2txt=auxtext, stopifmiss=FALSE)
-
-    ## Check that the strunitvars in auxlut are all in pltx
-    auxlut <- check.matchval(tab1=auxlut, tab2=pltx, var1=c(unitvars, strvars),
-		tab1txt=auxtext, tab2txt="plt", stopifmiss=FALSE)
-
-
-    ## Check getwt and calculate strata weights (proportion by estimation unit)
-    ###################################################################################
-    getwt <- pcheck.logical(getwt, varnm="getwt", title="Get strata weights?",
-		                  first="YES", gui=gui, stopifnull=TRUE)
-
-    if (getwt) {
-      ## Check getwtvar from strata table.
-      getwtvar <- pcheck.varchar(var2check=getwtvar, varnm="getwtvar", gui=gui,
-		          checklst=names(auxlut), caption="Acre variable?", stopifinvalid=FALSE)
-      if (is.null(getwtvar) || !getwtvar %in% names(auxlut)) {
-        if (strwtvar %in% names(auxlut)) {
-          #message("using strwtvar column for strata weights")
-          getwt <- FALSE
-        } else {
-          stop("getwtvar not in stratalut")
-        }
-      }
-    }
-  } else if (module %in% c("GB", "PB")) {
-
-    ## Add a column to identify one strata class for GB or PB modules
-    message("no strata")
-    strvar <- checknm("ONESTRAT", names(pltx))
-    strwtvar <- "strwt"
-    pltx[, (strvar) := 1]
-
-    auxlut <- unique(pltx[, c(unitvar2, unitvar), with=FALSE])
-    auxlut[, (strvar) := 1]
-    auxlut[, (strwtvar) := 1]
-
-    if (!is.null(P2POINTCNT)) {
-      P2POINTCNT[, (strvar) := 1]
-    }
-    getwt <- FALSE
-    getwtvar <- NULL
-    strvars <- c(strvars, strvar)
-    strata <- TRUE
-    strunitvars <- c(unitvars, strvars)
-
-  } else {
-    auxnmlst <- names(auxlut)
-    missvars <- {}
-
     if (is.null(auxlut)) {
       auxlut <- unique(pltx[, c(unitvar2, unitvar), with=FALSE])
     } else {
@@ -205,22 +98,126 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
         }
       }
     }
+    ## Keep adjustment variables in auxlut (i.e., from FIADB)
+    if (keepadjvars && !is.null(adjvars)) {
+      adjvars <- adjvars[adjvars %in% names(auxlut)]
+      if (length(adjvars) > 0) {
+        auxlutadj <- auxlut[, c(unitvars, strvars, adjvars), with=FALSE]
+      } else {
+        keepadjvars <- FALSE
+      }
+    }
+    
+    ## Define sumvars to aggregate
+    sumvars <- c(getwtvar, strwtvar, npixelvar)
+    
+    ## Aggregate strata by estimation unit to make sure no duplicate values exist
+    sumvars <- unique(sumvars[sumvars %in% names(auxlut)])
+    if (length(sumvars) > 0) {
+      auxlut[, (sumvars) := lapply(.SD, as.numeric), .SDcols=sumvars]
+      auxlut <- auxlut[, lapply(.SD, sum, na.rm=TRUE),
+                       by=c(unitvars, strvars), .SDcols=sumvars]
+      setnames(auxlut, c(unitvars, strvars, sumvars))
+    }
 
+    #setkeyv(auxlut, unitvars)
+    strunitvars <- c(unitvars, strvars)
+    
+    if (keepadjvars && nrow(auxlut) == nrow(auxlutadj)) {
+      auxlut <- merge(auxlut, auxlutadj, by=strunitvars)
+    }  
+    
+    ## Check if class of unitvar in auxlut matches class of unitvar in pltx
+    tabs <- check.matchclass(pltx, auxlut, c(unitvars, strvars),
+                             tab1txt="pltassgn", tab2txt="auxlut")
+    pltx <- tabs$tab1
+    auxlut <- tabs$tab2
+    
+    ## Check that the strunitvars in pltx are all in auxlut
+    pltx <- check.matchval(tab1=pltx, tab2=auxlut, var1=c(unitvars, strvars),
+                           tab1txt="plt", tab2txt=auxtext, stopifmiss=FALSE, subsetrows=TRUE)
+    
+    ## Check that the strunitvars in pltx are all in auxlut
+    pltx <- check.matchval(tab1=pltx, tab2=auxlut, var1=c(unitvars, strvars),
+                           tab1txt="plt", tab2txt=auxtext, stopifmiss=FALSE)
+    
+    ## Check that the strunitvars in auxlut are all in pltx
+    auxlut <- check.matchval(tab1=auxlut, tab2=pltx, var1=c(unitvars, strvars),
+                             tab1txt=auxtext, tab2txt="plt", stopifmiss=FALSE)
+    
+    
+    ## Check getwt and calculate strata weights (proportion by estimation unit)
+    ###################################################################################
+    getwt <- pcheck.logical(getwt, varnm="getwt", title="Get strata weights?",
+                            first="YES", gui=gui, stopifnull=TRUE)
+    
+    if (getwt) {
+      ## Check getwtvar from strata table.
+      getwtvar <- pcheck.varchar(var2check=getwtvar, varnm="getwtvar", gui=gui,
+                                 checklst=names(auxlut), caption="Acre variable?", stopifinvalid=FALSE)
+      if (is.null(getwtvar) || !getwtvar %in% names(auxlut)) {
+        if (strwtvar %in% names(auxlut)) {
+          #message("using strwtvar column for strata weights")
+          getwt <- FALSE
+        } else {
+          stop("getwtvar not in stratalut")
+        }
+      }
+    }
+  } else if (module %in% c("GB", "PB")) {
+    
+    ## Add a column to identify one strata class for GB or PB modules
+    #message("no strata")
+    strvar <- checknm("ONESTRAT", names(pltx))
+    strwtvar <- "strwt"
+    pltx[, (strvar) := 1]
+    
+    auxlut <- unique(pltx[, c(unitvar2, unitvar), with=FALSE])
+    auxlut[, (strvar) := 1]
+    auxlut[, (strwtvar) := 1]
+    
+    if (!is.null(P2POINTCNT)) {
+      P2POINTCNT[, (strvar) := 1]
+    }
+    getwt <- FALSE
+    getwtvar <- NULL
+    strvars <- c(strvars, strvar)
+    strata <- TRUE
+    strunitvars <- c(unitvars, strvars)
+    
+  } else {
+    auxnmlst <- names(auxlut)
+    missvars <- {}
+    
+    if (is.null(auxlut)) {
+      auxlut <- unique(pltx[, c(unitvar2, unitvar), with=FALSE])
+    } else {
+      if (any(grepl("ONEUNIT", unitvars))) {
+        unittest <- unitvars[any(grepl("ONEUNIT", unitvars))]
+        if (length(unittest) > 1) {
+          stop("more than one ONEUNIT variable")
+        }
+        if (!unittest %in% names(auxlut)) {
+          auxlut[, (unittest) := 1]
+        }
+      }
+    }
+    
     ## Check predictors
     ############################################################################
     if (length(c(strvar, predfac)) > 0) {
       missvars <- c(missvars,
-		        predfac[sapply(c(strvar, predfac),
-			        function(x) sum(grepl(x, auxnmlst)) == 0)])
+                    predfac[sapply(c(strvar, predfac),
+                                   function(x) sum(grepl(x, auxnmlst)) == 0)])
     }
-
+    
     ## Check continuous variables
     ############################################################################
     predcon <- prednames[!prednames %in% predfac]
     if (length(predcon) > 0) {
       missvars <- c(missvars, predcon[which(!predcon %in% auxnmlst)])
     }
- 
+    
     if (length(missvars) > 0) {
       for (mvar in missvars) {
         if (any(grepl(mvar, auxnmlst))) {
@@ -235,38 +232,43 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
         }
       }
     }
-
+    
     ## Check for NA values in continuous variables in auxlut
     ############################################################################
     aux.na <- sapply(predcon,
-		        function(x, auxlut){ sum(is.na(auxlut[,x, with=FALSE])) }, auxlut)
+                     function(x, auxlut){ sum(is.na(auxlut[,x, with=FALSE])) }, auxlut)
     if (any(aux.na) > 0) {
       message(aux.na[aux.na > 0], " NA values in variable: ",
-		             paste(names(aux.na[aux.na > 0]), collapse=", "))
+              paste(names(aux.na[aux.na > 0]), collapse=", "))
       if (na.rm)
         auxlut <- na.omit(auxlut, cols=predcon)
     }
   }
-
+ 
   if (module == "MA") {
     auxnmlst <- names(auxlut)
     ## Check npixelvar from strata table.
     ############################################################################
     npixelvar <- pcheck.varchar(var2check=npixelvar, varnm="npixelvar", gui=gui,
-		checklst=auxnmlst, caption="Acre variable?", stopifinvalid=TRUE)
-
+                                checklst=auxnmlst, caption="Acre variable?", stopifinvalid=TRUE)
+    
     ## Create data frame of number of pixels by estimation unit
     ############################################################################
     if (npixelvar %in% auxnmlst) {
       npixels <- unique(auxlut[, c(unitvar, npixelvar), with=FALSE])
-      auxlut$npixels <- NULL
+      auxlut[[npixelvar]] <- NULL
     }
   }
   
   ## Get order of unitvar for collapsing
   if (!is.null(unitlevels) && !is.factor(auxlut[[unitvar]])) {
     auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels = unitlevels)
-	  setorderv(auxlut, c(unitvar, unitvar2))
+    setorderv(auxlut, c(unitvar, unitvar2))
+    
+    if (!is.null(unitarea)) {
+      unitarea[[unitvar]] <- factor(unitarea[[unitvar]], levels = unitlevels)
+      setorderv(unitarea, c(unitvar, unitvar2))
+    }
   }
 
   ##################################################################################
@@ -282,31 +284,33 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
       unitarea[[unitvar21]] <- paste(unitarea[[unitvar2]], unitarea[[unitvar]], sep="-")
       unitarea[, c(unitvar, unitvar2) := NULL]
     }
-  
+
     if (!is.null(RHGlut)) {
       RHGlut[[unitvar21]] <- paste(RHGlut[[unitvar2]], RHGlut[[unitvar]], sep="-")
       RHGlut[, c(unitvar, unitvar2) := NULL]
     }
-	
+
     unitvar <- unitvar21
-	  unitlevels <- unique(auxlut[[unitvar]])
-	  auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels = unitlevels)
+    unitlevels <- unique(auxlut[[unitvar]])
+    auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels = unitlevels)
     pltx[[unitvar]] <- factor(pltx[[unitvar]], levels=unitlevels)
   }
-  
+
   ## Merge P2POINTCNT to auxlut
   ##################################################
-  if (!is.null(P2POINTCNT) && !"P2POINTCNT" %in% names(auxlut)) {
+  p2pointcntnm <- findnm("P2POINTCNT", names(auxlut), returnNULL = TRUE)
+  if (!is.null(P2POINTCNT) && !is.null(p2pointcntnm)) {
 
     ## Check if class of unitvar in auxlut matches class of unitvar in P2POINTCNT
     tabs <- check.matchclass(P2POINTCNT, auxlut, strunitvars,
-		tab1txt="P2POINTCNT", tab2txt="auxlut")
+                             tab1txt="P2POINTCNT", tab2txt="auxlut")
     P2POINTCNT <- tabs$tab1
     auxlut <- tabs$tab2
 
     ## Check that the strunitvars in pltx are all in auxlut
     auxlut <- merge(auxlut, P2POINTCNT, by=strunitvars, all.x=TRUE)
     auxlut[is.na(auxlut)] <- 0
+    auxlut$NBRPLOTS <- NULL
   }
 
   ## Redefine strunitvars
@@ -315,12 +319,22 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   ## Make unitvar a factor for retaining order for collapsing{
   if (!is.factor(auxlut[[unitvar]])) {
     if (is.null(unitlevels)) {
-	    unitlevels <- unique(auxlut[[unitvar]])
-	  }
+      unitlevels <- unique(auxlut[[unitvar]])
+    }
     auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels=unitlevels)
     pltx[[unitvar]] <- factor(pltx[[unitvar]], levels=unitlevels)
   }
-
+  
+  # ## Make strvar a factor for retaining order for collapsing
+  # if (!is.factor(auxlut[[strvar]])) {
+  #   if (is.null(stratalevels)) {
+  #     stratalevels <- sort(unique(auxlut[[strvar]]))
+  #   }
+  #   auxlut[[strvar]] <- factor(auxlut[[strvar]], levels=stratalevels)
+  #   pltx[[strvar]] <- factor(pltx[[strvar]], levels=stratalevels)
+  # }
+  
+  
   ###################################################################################
   ## Check number of plots by unitvar
   ##	 (including partially sampled plots - COND_STATUS_CD=5)
@@ -338,43 +352,64 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     warning("minplotnum.unit should be at least 2")
     #minplotnum.unit <- 2
   }
-
+  
   if (strata) {
     if (minplotnum.strat > minplotnum.unit) {
+      message("minplotnum.unit (", minplotnum.unit, 
+              ") is less than minplotnum.strat (", minplotnum.strat, ")... ",
+              "changing minplotnum.unit to ", minplotnum.strat)
       minplotnum.strat <- minplotnum.unit
     }
   } else {
     minplotnum.strat <- 0
   }
-  pltcnts <- check.pltcnt(pltx=pltx, puniqueid=puniqueid,
-		unitlut=auxlut, unitvars=unitvar, strvars=strvar,
-		stopiferror=FALSE, showwarnings=TRUE, minplotnum.unit=minplotnum.unit,
-		minplotnum.strat=minplotnum.strat)
+
+  pltcnts <- check.pltcnt(pltx = pltx, puniqueid = puniqueid,
+		                      unitlut = copy(auxlut), 
+		                      unitvars = unitvar, strvars = strvar,
+		                      stopiferror = FALSE, showwarnings = TRUE, 
+		                      minplotnum.unit = minplotnum.unit,
+		                      minplotnum.strat = minplotnum.strat)
   auxlut <- pltcnts$unitlut
   errtab <- pltcnts$errtab
   nostrat <- pltcnts$nostrat
+  
+  ## order by unitvar and strvar
+  if (module == "GB" && !is.null(strvar)) {
+    errtab <- errtab[order(errtab[[unitvar]], errtab[[strvar]]),]
+    auxlut <- auxlut[order(auxlut[[unitvar]], auxlut[[strvar]]),]
+  } else {
+    errtab <- errtab[order(errtab[[unitvar]]),]
+    auxlut <- auxlut[order(auxlut[[unitvar]]),]
+  }
 
   ## If unit.action="remove", remove estimation with less than minplotnum.unit plots
+  ## If unit.action="keep", return estimation units with less than minplotnum.unit as NA
+  unitltmin <- 0
+  
   if (any(auxlut$n.total < minplotnum.unit)) {
-    unitltmin <- unique(errtab[[unitvar]][errtab$n.total < minplotnum.unit])
-
-    if (length(unitltmin) > 0) {
-      if (unit.action == "remove") {
-        message("removing domains with plots less than ", minplotnum.unit,
-		         ": ", toString(unitltmin))
-        auxlut <- auxlut[!auxlut[[unitvar]] %in% unitltmin, ]
-        pltx <- pltx[!pltx[[unitvar]] %in% unitltmin, ]
-        unitarea <- unitarea[!unitarea[[unitvar]] %in% unitltmin, ]
-        errtab <- errtab[!errtab[[unitvar]] %in% unitltmin, ]
-      } else if (unit.action == "keep") {
-        message("there are ", length(unitltmin), " units with less than minplotnum.unit (", 
-		            minplotnum.unit, ") plots:\n", 
-		            toString(unitltmin)) 
-        message("if want to combine units that are less than minplotnum.unit, ",
-		            "set unit.action='combine' in unit.opts parameter... ",
-				        "\ncheck returned object, stratwarnlut\n")		   
-        minplotnum.unit <- 0
-        #errtab <- errtab[, errtyp := "none"]
+    unitltmin <- unique(auxlut[[unitvar]][auxlut$n.total < minplotnum.unit])
+    if (length(unitltmin) == 0) unitltmin <- NULL
+    if (!is.null(unitltmin)) {
+      if (unit.action %in% c("remove", "keep")) {
+        
+        if (unit.action == "remove") {
+          message("removing domains with plots less than ", minplotnum.unit,
+                  ": ", toString(unitltmin))
+        } else {
+          warntab <- ifelse (module == "GB", "stratwarnlut", "unitwarnlut")
+          message("there are ", length(unitltmin), " units with less than minplotnum.unit (", 
+                  minplotnum.unit, ") plots:\n", 
+                  toString(unitltmin)) 
+          message("returning NA values for these units...")
+          message("if want to combine units that are less than minplotnum.unit, ",
+                  "set unit.action='combine' in unit.opts parameter... ",
+                  "\ncheck returned object, ", warntab, "\n")	
+          
+        }
+        auxlut <- auxlut[!auxlut[[unitvar]] %in% unitltmin,]
+        unitltmin <- unique(auxlut[[unitvar]][auxlut$n.total < minplotnum.unit])
+        if (length(unitltmin) == 0) unitltmin <- NULL
       }
     }
   }
@@ -389,6 +424,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   ## Collapse strata and/or estimation unit classes if errtab warnings
   ###################################################################################
   if (!nonresp && any(errtab$errtyp == "warn")) {
+    auxlut <- auxlut[auxlut[[unitvar]] %in% errtab[[unitvar]],]
     if (any(c(getwtvar, npixelvar, strwtvar) %in% names(auxlut))) {
       vars2combine <- unique(c(vars2combine, c(getwtvar, npixelvar, strwtvar)))
       vars2combine <- vars2combine[vars2combine %in% names(auxlut)]
@@ -397,6 +433,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     if (minplotnum.strat > minplotnum.unit) {
       minplotnum.strat <- minplotnum.unit
     }
+
     unitcombine <- ifelse(unit.action == 'combine', TRUE, FALSE)
     collapse <- strat.collapse(stratacnt=auxlut, 
                                pltstratx=pltx, 
@@ -407,11 +444,13 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
                                stratcombine=stratcombine, 
                                unitcombine=unitcombine, 
                                vars2combine=vars2combine)						 
-
     if ((stratcombine || unitcombine) && !is.null(collapse$unitstrgrplut)) {
-	    message("check strata groups in returned object, unitstrgrplut\n")
+	    message("check strata groups in returned object, stratcombinelut\n")
       unitstrgrplut <- collapse$unitstrgrplut
 	    unitstrgrplut <- merge(errtab, unitstrgrplut, by=strunitvars)
+	    if (!is.null(unitvar2)) {
+	      unitstrgrplut[, (unitvars) := tstrsplit(get(unitvar), "-", fixed=TRUE)]
+	    }
     }
 
     ## Get new variable definitions
@@ -497,7 +536,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
       }
     }
   }
-  
+ 
   ##################################################################################
   ## Check estimation unit values from auxlut with unitarea
   ##################################################################################
@@ -553,11 +592,18 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   #} else {
     setcolorder(auxlut, c(strunitvars, names(auxlut)[!names(auxlut) %in% strunitvars]))
   #}
+    
+  if (!is.null(prednames) && standardize) {
+    standardized <- preds.standardize(plt=pltx, aux=auxlut, prednames=prednames)
+    pltx <- standardized$plt
+    auxlut <- standardized$aux
+  }
+    
 
-  returnlst <- list(pltx=as.data.table(pltx),
-		auxlut=as.data.table(auxlut),
-		unitvar=unitvar, unitvars=unitvars,
-		prednames=prednames, predfac=predfac)
+  returnlst <- list(pltx = as.data.table(pltx),
+		                auxlut = as.data.table(auxlut),
+		                unitvar = unitvar, unitvars = unitvars,
+		                prednames = prednames, predfac = predfac)
 
   if (!is.null(unitarea)) {
     setkeyv(unitarea, unitvar)
@@ -568,12 +614,6 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     returnlst$npixelvar <- npixelvar
   }
 
-  if (!is.null(prednames) && standardize) {
-    standardized <- preds.standardize(plt=pltx, aux=auxlut, prednames=prednames)
-    pltx <- standardized$plt
-    auxlut <- standardized$aux
-  }
-
   if (strata) {
     returnlst$strvar <- strvar
     if (module %in% c("GB", "PB")) {
@@ -602,12 +642,17 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     if (!is.null(getwtvar)) {
       returnlst$getwtvar <- getwtvar
     }
-    if (!is.null(unitstrgrplut)) {
-      returnlst$stratcombinelut <- unitstrgrplut
-    } else if (!is.null(errtab)) {
-	    returnlst$stratwarnlut <- errtab
-	  }
   }
 
+  if (!is.null(unitstrgrplut)) {
+    returnlst$stratcombinelut <- data.frame(unitstrgrplut, check.names=FALSE)
+  } 
+  if (!is.null(errtab)) {
+	  returnlst$stratwarnlut <- errtab
+  }
+  #if (length(unitltmin) > 0 &&  unit.action == "keep") {
+    returnlst$unitltmin <- unitltmin
+  #}
+  
   return(returnlst)
 }
