@@ -142,7 +142,8 @@ check.unitarea <- function(unitarea, pltx, unitvars, areavar="ACRES",
     unitarea <- check.matchval(unitarea, pltx, unitvars,
 		tab1txt=removetext, tab2txt="plt", subsetrows=removeunits)
 
-    if (!is.null(vars2keep) && all(vars2keep %in% names(unitarea))) {
+    vars2keep <- vars2keep[vars2keep %in% names(unitarea)]
+    if (length(vars2keep) > 0) {
       ## Sum area by unitvars
       unitarea <- unitarea[, lapply(.SD, sum, na.rm=TRUE), 
            by=c(unitvars, vars2keep), .SDcols=areavar]
