@@ -15,7 +15,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
   rowvar <- ifelse(is.null(rowvar), "NONE", rowvar)
   colvar <- ifelse(is.null(colvar), "NONE", colvar)
   
-
+  
   #####  TITLE INFO FOR TABLE COLUMNS
   ########################################################
   if (allin1) {
@@ -24,28 +24,28 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     title.yhat <- "Estimate"
     title.yhat.pse <- "Percent Sampling Error"
   }
-
+  
   ## Check if a total table exists
   if (!is.null(unit_totest)) gtotal <- TRUE
-
+  
   if (!is.null(title.ref) && title.ref != "") {
     title.ref <- paste(";", title.ref)
   }
-
+  
   ## Define est.var name
   estnm.var <- paste0(estnm, ".var")
   senm <- paste0(estnm, ".se")
   estnm2 <- ifelse(esttype == "RATIO", "rhat", estnm)
   senm2 <- paste0(estnm2, ".se")
-
-
+  
+  
   ## Get conversion number
   dividebynum <- NULL
-
+  
   if (!is.null(divideby)) {
     dividebynum <- ifelse(divideby == "hundred", 100,
-				ifelse(divideby == "thousand", 1000,
-					ifelse(divideby == "million", 1000000, 1)))
+                          ifelse(divideby == "thousand", 1000,
+                                 ifelse(divideby == "million", 1000000, 1)))
     estnmd <- paste(estnm, divideby, sep=".")
     senmd <- paste(senm, divideby, sep=".")
   } else {
@@ -54,7 +54,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
   }
   estnmd <- ifelse(esttype == "RATIO", "rhat", estnmd)
   senmd <- ifelse(esttype == "RATIO", "rhat.se", senmd)
-
+  
   rnames <- rowvar
   title.rnames <- title.rowvar
   totals <- "Total"
@@ -64,11 +64,11 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     totals <- c(totals, "Total")
   }
   rnbr <- length(rnames)
-
+  
   ## Set up lists
   returnlst <- list()
   titlelst <- list()
- 
+  
   ## sumunits = FALSE
   if (!is.null(unit_totest)) {
     if (esttype == "RATIO") {
@@ -87,7 +87,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       if (!is.null(char.width) && char.width == -Inf) char.width <- 0
     }
   }
-
+  
   if (!is.null(unit_rowest)) {
     if (esttype == "RATIO") {
       unit_rowest <- suppressWarnings(getrhat(unit_rowest))
@@ -102,10 +102,10 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     }
     if (allin1) {
       char.width <- max(char.width,
-		max(nchar(na.omit(round(unit_rowest[[psenm]], pseround)))))
+                        max(nchar(na.omit(round(unit_rowest[[psenm]], pseround)))))
     }
   }
-
+  
   if (!is.null(unit_colest)) {
     if (esttype == "RATIO") {
       unit_colest <- suppressWarnings(getrhat(unit_colest))
@@ -120,10 +120,10 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     }
     if (allin1) {
       char.width <- max(char.width,
-		max(nchar(na.omit(round(unit_colest[[psenm]], pseround)))))
+                        max(nchar(na.omit(round(unit_colest[[psenm]], pseround)))))
     }
   }
-
+  
   if (!is.null(unit_grpest)) {
     if (esttype == "RATIO") {
       unit_grpest <- suppressWarnings(getrhat(unit_grpest))
@@ -138,47 +138,27 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     }
     if (allin1) {
       char.width <- max(char.width,
-		max(nchar(na.omit(round(unit_grpest[[psenm]], pseround)))))
+                        max(nchar(na.omit(round(unit_grpest[[psenm]], pseround)))))
     }
-	
-	# ## Check for matching levels in x and xunique
-    # if (!is.null(uniquerow)) {
-      # chklevels <- checklevels(x = unit_grpest, 
-	                         # uniquex = uniquerow,
-							 # xvar = rowvar) 
-	  # unit_grpest <- chklevels$x
-      # uniquerow <- chklevels$uniquex	
-    # }
-    # if (!is.null(uniquecol)) {
-      # chklevels <- checklevels(x = unit_grpest, 
-	                         # uniquex = uniquecol,
-							 # xvar = colvar) 
-	  # unit_grpest <- chklevels$x
-      # uniquecol <- chklevels$uniquex	
-    # }
- 
-    # chklevels <- checklevels(x = unit_colest, 
-	                         # uniquex = uniquecol,
-							 # xvar = colvar) 
-	# unit_colest <- chklevels$x
-  # }
-
-	
   }
-
+  
   if (sumunits) {
     ## Group estimates
     #if (!is.null(uniquerow))
     #  keepvars.row <- names(uniquerow)[names(uniquerow) != rowvar]
     #if (!is.null(uniquecol))
     #  keepvars.col <- names(uniquecol)[names(uniquecol) != colvar]
-	keepvars.row=keepvars.col <- NULL
+	  keepvars.row=keepvars.col <- NULL
 
     ## GROUP TOTAL TABLE
     if (!is.null(unit_totest)) {
-      totest <- groupUnits(unit_totest, estncol=estnm, estncol.var=estnm.var,
-		domain="TOTAL", esttype=esttype, rowgrpnm=rowgrpnm, unitvar=unitvar,
-		areavar=areavar, phototype=phototype, photoratio=photoratio)
+      totest <- 
+        groupUnits(unit_totest, 
+                   estncol = estnm, estncol.var = estnm.var,
+		               domain = "TOTAL", esttype = esttype, 
+		               rowgrpnm = rowgrpnm, 
+		               unitvar = unitvar, areavar = areavar,
+		               phototype = phototype, photoratio = photoratio)
       if (esttype != "RATIO" && !is.null(dividebynum)) {
         totest[[estnmd]] <- totest[[estnm2]] / dividebynum
         totest[[senmd]] <- totest[[senm2]] / dividebynum
@@ -192,10 +172,13 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       }
     }
     if (!is.null(unit_rowest)) {
-      rowest <- groupUnits(tabest=unit_rowest, domain=rowvar, estncol=estnm,
-			estncol.var=estnm.var, esttype=esttype, rowgrpnm=rowgrpnm,
-			unitvar=unitvar, areavar=areavar, phototype=phototype,
-			photoratio=photoratio, keepvars=keepvars.row)
+      rowest <- 
+        groupUnits(tabest = unit_rowest, domain = rowvar, 
+                   estncol = estnm, estncol.var = estnm.var, 
+                   esttype = esttype, rowgrpnm = rowgrpnm,
+			             unitvar = unitvar,  
+			             phototype = phototype, photoratio = photoratio, 
+			             keepvars = keepvars.row)
       if (esttype != "RATIO" && !is.null(dividebynum)) {
         rowest[[estnmd]] <- rowest[[estnm2]] / dividebynum
         rowest[[senmd]] <- rowest[[senm2]] / dividebynum
@@ -207,14 +190,17 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       rowest[[psenm]] <- rowest[[psenm]]
       if (allin1) {
         char.width <- max(char.width,
-		max(nchar(na.omit(round(rowest[[psenm]], pseround)))))
+		        max(nchar(na.omit(round(rowest[[psenm]], pseround)))))
       }
     }
-    if (!is.null(unit_colest)) {
-      colest <- groupUnits(tabest=unit_colest, domain=colvar, estncol=estnm,
-			estncol.var=estnm.var, esttype=esttype, unitvar=unitvar,
-			areavar=areavar, phototype=phototype, photoratio=photoratio,
-			keepvars=keepvars.col)
+	  if (!is.null(unit_colest)) {
+      colest <- 
+        groupUnits(tabest = unit_colest, domain = colvar, 
+                   estncol = estnm, estncol.var = estnm.var, 
+                   esttype = esttype, 
+                   unitvar = unitvar,  
+                   phototype = phototype, photoratio = photoratio,
+			             keepvars = keepvars.col)
       if (esttype != "RATIO" && !is.null(dividebynum)) {
         colest[[estnmd]] <- colest[[estnm2]] / dividebynum
         colest[[senmd]] <- colest[[senm2]] / dividebynum
@@ -226,15 +212,18 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       colest[[psenm]] <- colest[[psenm]]
       if (allin1) {
         char.width <- max(char.width,
-		max(nchar(na.omit(round(colest[[psenm]], pseround)))))
+		       max(nchar(na.omit(round(colest[[psenm]], pseround)))))
       }
-    }	
+	  }	
     if (!is.null(unit_grpest)) {
-      grpest <- groupUnits(tabest=unit_grpest, domain=rowvar, estncol=estnm,
-			estncol.var=estnm.var, domvar2=colvar, esttype=esttype,
-			rowgrpnm=rowgrpnm, unitvar=unitvar, areavar=areavar,
-			phototype=phototype, photoratio=photoratio,
-			keepvars=c(keepvars.row, keepvars.col))
+      grpest <- 
+        groupUnits(tabest = unit_grpest, domain = rowvar, 
+                   estncol = estnm, estncol.var = estnm.var, 
+                   domvar2 = colvar, esttype = esttype,
+			             rowgrpnm = rowgrpnm, 
+			             unitvar = unitvar, 
+			             phototype = phototype, photoratio = photoratio,
+			             keepvars = c(keepvars.row, keepvars.col))
       if (esttype != "RATIO" && !is.null(dividebynum)) {
         grpest[[estnmd]] <- grpest[[estnm2]] / dividebynum
         grpest[[senmd]] <- grpest[[senm2]] / dividebynum
@@ -246,7 +235,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       grpest[[psenm]] <- grpest[[psenm]]
       if (allin1) {
         char.width <- max(char.width,
-		max(nchar(na.omit(round(grpest[[psenm]], pseround)))))
+		       max(nchar(na.omit(round(grpest[[psenm]], pseround)))))
       }
     }
   }
@@ -259,31 +248,38 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     if (sumunits) {
       if (rowvar == "TOTAL") {
         if (allin1) {
-          estpse <- data.frame(TOTAL="Total", allin1f(round(totest[[estnmd]], estround),
-			round(totest[[psenm]], pseround), estnull=estnull, psenull=psenull,
-			char.width=char.width), stringsAsFactors=FALSE)
+          estpse <- 
+            data.frame(TOTAL = "Total", 
+                       allin1f(round(totest[[estnmd]], estround),
+			                 round(totest[[psenm]], pseround), 
+			                 estnull = estnull, psenull = psenull,
+			                 char.width = char.width), 
+			                 stringsAsFactors = FALSE)
           setnames(estpse, c("TOTAL", title.yhatpse))
-
         } else {
-          estpse <- data.table(TOTAL="Total",
-			totest[, c(estnmd, psenm), with=FALSE],
-			stringsAsFactors=FALSE)
-          estpse[[estnmd]] <- round(estpse[[estnmd]], estround)
-          estpse[[psenm]] <- round(estpse[[psenm]], pseround)
+          estpse <- 
+            data.table(TOTAL = "Total",
+			                 totest[, c(estnmd, psenm), with=FALSE], stringsAsFactors=FALSE)
+                       estpse[[estnmd]] <- round(estpse[[estnmd]], estround)
+                       estpse[[psenm]] <- round(estpse[[psenm]], pseround)
           names(estpse) <- c("TOTAL", title.yhat, title.yhat.pse)
         }
         rowtotal <- FALSE
 
       } else {  ##  rowvar != "TOTAL"
+        
         ## Get estimates
-        estcross <- crosstabx(rowest, rowvar, estnmd, psenm, allin1=allin1,
-		estnull=estnull, psenull=psenull, char.width=char.width,
-		estround=estround, pseround=pseround)
-
+        estcross <- 
+          crosstabx(rowest, rowvar, estnmd, psenm, allin1=allin1,
+		                estnull = estnull, psenull = psenull, 
+		                char.width = char.width,
+		                estround = estround, pseround = pseround)
         if (allin1) {
-          tottab <- data.frame(TOTAL="Total", allin1f(totest[[estnmd]],
-			totest[[psenm]], char.width=char.width, estnull=estnull,
-			psenull=psenull, estround=estround, pseround=pseround), stringsAsFactors=FALSE)
+          tottab <- 
+            data.frame(TOTAL = "Total", allin1f(totest[[estnmd]],
+			                 totest[[psenm]], char.width=char.width, estnull=estnull,
+			                 psenull=psenull, estround=estround, pseround=pseround), 
+			                 stringsAsFactors=FALSE)
           setnames(tottab, c("TOTAL", title.yhatpse))
 
           estpse <- estcross
@@ -332,9 +328,9 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       if (savedata) {
         suppressWarnings(
         save1tab(tab=setDF(estpse), tab.title=title.estpse, outfn=outfn.estpse,
-			outfolder=outfolder, allin1=allin1, coltitlerow=FALSE,
-			addtitle=addtitle, rowtotal=rowtotal, outfn.date=outfn.date,
-			overwrite=overwrite, charvars=title.rnames, cols2format=title.yhat) )
+			           outfolder=outfolder, allin1=allin1, coltitlerow=FALSE,
+			           addtitle=addtitle, rowtotal=rowtotal, outfn.date=outfn.date,
+			           overwrite=overwrite, charvars=title.rnames, cols2format=title.yhat) )
       }
 
     } else {  ## colvar == NONE, sumunits = FALSE
@@ -346,13 +342,15 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
       ## GET TOTAL TABLE
       if (!is.null(unit_totest)) {
         if (allin1) {
-            ## Get table with estimates by unitvar
-             estpsetot <- data.table(unit_totest[[unitvar]],
-			crosstabx(x=unit_totest, unitvar, estnm=estnmd,
-				psenm=psenm, allin1=TRUE, estnull=estnull,
-				psenull=psenull, char.width=char.width,
-				estround=estround, pseround=pseround))
-            setnames(estpsetot, c(title.unitvar, title.yhatpse))
+          ## Get table with estimates by unitvar
+          estpsetot <- data.table(unit_totest[[unitvar]],
+			            crosstabx(x = unit_totest, 
+			                      xvar = "TOTAL",
+			                      estnm = estnmd, psenm = psenm, allin1 = TRUE, 
+			                      estnull = estnull, psenull = psenull, 
+				                    char.width = char.width,
+				                    estround = estround, pseround = pseround))
+          setnames(estpsetot, c(title.unitvar, title.yhatpse))
         } else {
           ## GET TABLE OF ESTIMATES WITH TITLES
           estpsetot <- data.table(unit_totest[,c(unitvar, estnmd, psenm), with=FALSE])
@@ -379,9 +377,13 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
         if (!is.null(totunit)) {
           totunit <- setDF(totunit)
           if (allin1) {
-            totunit <- data.frame(TOTAL="Total", allin1f(totunit[[estnmd]], totunit[[psenm]],
-			estnull=estnull, psenull=psenull, char.width=char.width, estround=estround,
-			pseround=pseround), stringsAsFactors=FALSE)
+            totunit <- data.frame(TOTAL = "Total", 
+                                  allin1f(totunit[[estnmd]], 
+                                          totunit[[psenm]],
+			                            estnull = estnull, psenull = psenull, 
+			                            char.width = char.width, 
+			                            estround = estround,
+			                            pseround = pseround), stringsAsFactors = FALSE)
             setnames(totunit, c(unitvar, title.yhatpse))
           } else {
             totunit <- c("TOTAL", totunit[, c(estnmd, psenm)])
@@ -401,9 +403,9 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
         if (savedata)
           suppressWarnings(
           save1tab(tab=est2return, tab.title=title.estpse,
-			outfn=outfn.estpse, outfolder=outfolder, allin1=allin1,
-			coltitlerow=FALSE, rowtotal=FALSE, addtitle=addtitle,
-			outfn.date=outfn.date, overwrite=overwrite, cols2format=title.yhat))
+			             outfn=outfn.estpse, outfolder=outfolder, allin1=allin1,
+			             coltitlerow=FALSE, rowtotal=FALSE, addtitle=addtitle,
+			             outfn.date=outfn.date, overwrite=overwrite, cols2format=title.yhat))
 
       } else {  ## rowvar != "TOTAL"
 
@@ -421,16 +423,20 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
         }
         if (!is.null(unit_totest) && !is.null(uniquecol)) {
           unit_totest <- add0unit(x=unit_totest, xvar=unitvar, uniquex=uniquecol,
-			xvar.add0=TRUE)
+			                            xvar.add0=TRUE)
         }
 
         ## Get table of estimates
-        estpsecross <- crossxtab(group.est=unit_rowest, rowvar.est=rowunit,
-			colvar.est=unit_totest, total.est=totunit, rowvar=rowvar,
-			colvar=unitvar, estnm=estnmd, psenm=psenm, allin1=allin1,
-			rowgrp=rowgrp, rowgrpnm=rowgrpnm, title.rnames=title.rnames,
-			estround=estround, pseround=pseround, estnull=estnull,
-			psenull=psenull, char.width=char.width)
+        estpsecross <- crossxtab(group.est = unit_rowest, 
+                                 rowvar.est = rowunit, colvar.est = unit_totest, 
+                                 total.est = totunit, 
+			                           rowvar = rowvar, colvar = unitvar, 
+			                           estnm = estnmd, psenm = psenm, allin1 = allin1,
+			                           rowgrp = rowgrp, rowgrpnm = rowgrpnm, 
+			                           title.rnames = title.rnames,
+			                           estround = estround, pseround = pseround, 
+			                           estnull = estnull, psenull = psenull, 
+			                           char.width = char.width)
 
         if (esttype != "RATIO") {
           if (!is.null(unit_totest)) {
@@ -441,7 +447,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
             sumest <- sum(unit_rowest[[estnm]], na.rm=TRUE)
             if (!(sumest < (totest + 100) & sumest > (totest - 100)))
               warning("the total estimate does not match sum of attributes.. difference of ",
-			abs(sumest-totest))
+			                 abs(sumest-totest))
           }
         }
 
@@ -458,9 +464,9 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
 
             estpsetab <- data.table(esttab, psetab[[title.yhat.pse]])
             if (is.numeric(estnull)) estpsetab[[title.yhat]] <-
-				as.numeric(estpsetab[[title.yhat]])
+				                    as.numeric(estpsetab[[title.yhat]])
             if (is.numeric(psenull)) estpsetab[[title.yhat.pse]] <-
-				as.numeric(estpsetab[[title.yhat.pse]])
+				                    as.numeric(estpsetab[[title.yhat.pse]])
             names(estpsetab) <- c(title.rnames, title.yhat, title.yhat.pse)
           }
 
@@ -474,10 +480,10 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
               ## SAVE TO FILE
               suppressWarnings(
               save1tab(tab=estpsetab, tab.title=title.estpse,
-			outfn=outfn.estpse, outfolder=outfolder, allin1=allin1,
-			coltitlerow=FALSE, rowtotal=TRUE, addtitle=addtitle,
-			outfn.date=outfn.date, overwrite=overwrite,
-			charvars=title.rnames, cols2format=title.yhat))
+			                 outfn=outfn.estpse, outfolder=outfolder, allin1=allin1,
+			                 coltitlerow=FALSE, rowtotal=TRUE, addtitle=addtitle,
+			                 outfn.date=outfn.date, overwrite=overwrite,
+			                 charvars=title.rnames, cols2format=title.yhat))
         } else {  # > 1 unit
 
           if (allin1) {
@@ -489,10 +495,10 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
               ## SAVE TO FILE
               suppressWarnings(
               save1tab(tab=estpsecross, tab.title=title.estpse,
- 				outfn=outfn.estpse, outfolder=outfolder, allin1=TRUE,
-				coltitlerow=FALSE, coltitle=title.unitvar, rowtotal=TRUE,
-				addtitle=addtitle, outfn.date=outfn.date, overwrite=overwrite,
-				charvars=title.rnames))
+ 				               outfn=outfn.estpse, outfolder=outfolder, allin1=TRUE,
+				               coltitlerow=FALSE, coltitle=title.unitvar, rowtotal=TRUE,
+				               addtitle=addtitle, outfn.date=outfn.date, overwrite=overwrite,
+				               charvars=title.rnames))
           } else {
             est2return <- estpsecross$est
             pse2return <- estpsecross$pse
@@ -506,10 +512,10 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
             ## SAVE TO FILE
              suppressWarnings(
               save2tabs(tab1=est2return, tab2=pse2return,
-				tab1.title=title.est, tab2.title=title.pse, outfn.estpse=outfn.estpse,
- 				outfolder=outfolder, coltitlerow=TRUE, coltitle=title.unitvar,
-				addtitle=addtitle, rowtotal=rowtotal, rnames=rnames,
-				outfn.date=outfn.date, overwrite=overwrite))
+				                tab1.title=title.est, tab2.title=title.pse, outfn.estpse=outfn.estpse,
+ 				                outfolder=outfolder, coltitlerow=TRUE, coltitle=title.unitvar,
+				                addtitle=addtitle, rowtotal=rowtotal, rnames=rnames,
+				                outfn.date=outfn.date, overwrite=overwrite))
           }
         }
       }
@@ -525,16 +531,30 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
 #      estunits <- unique(unit_grpest[[unitvar]])
 #      numunits <- length(estunits)
       numunits <- 1
-      tabs <- crossxbyunit(unit=NULL, unit_grpest=grpest,
-		unit_rowest=rowest, unit_colest=colest, unit_totest=totest,
-		unitvar=unitvar, rowvar=rowvar, colvar=colvar,
-		estnm=estnmd, psenm=psenm, allin1, char.width, estnull, psenull,
-		estround=estround, pseround=pseround,
-		rowgrp=rowgrp, rowgrpnm=rowgrpnm, title.rnames=title.rnames, 
-		numunits=numunits, savedata=savedata, addtitle,
-		returntitle, outfn.estpse, title.estpse, title.est, title.pse,
-		title.ref, outfolder, outfn.date, overwrite, esttype, phototype,
-		rnames, title.colvar, title.unitvar)
+      tabs <- 
+        crossxbyunit(unit = NULL, unit_grpest = grpest,
+		                 unit_rowest = rowest, unit_colest = colest, 
+		                 unit_totest = totest,
+		                 unitvar = unitvar, 
+		                 rowvar = rowvar, colvar = colvar,
+		                 estnm = estnmd, psenm = psenm, 
+		                 allin1 = allin1, char.width = char.width, 
+		                 estnull = estnull, psenull = psenull,
+		                 estround = estround, pseround = pseround,
+		                 rowgrp = rowgrp, rowgrpnm = rowgrpnm, 
+		                 title.rnames = title.rnames, 
+		                 numunits = numunits, 
+		                 savedata = savedata, addtitle = addtitle,
+		                 returntitle = returntitle, 
+		                 outfn.estpse = outfn.estpse, 
+		                 title.estpse = title.estpse, 
+		                 title.est = title.est, title.pse = title.pse,
+		                 title.ref = title.ref, 
+		                 outfolder = outfolder, outfn.date = outfn.date, 
+		                 overwrite = overwrite, 
+		                 esttype = esttype, phototype = phototype,
+		                 rnames = rnames, 
+		                 title.colvar = title.colvar, title.unitvar = title.unitvar)
       est2return <- tabs[[1]]
       if (length(tabs) == 2)
         pse2return <- tabs[[2]]
@@ -542,17 +562,29 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
     } else {  ## colvar != "NONE" & sumunits == FALSE
       estunits <- unique(unit_grpest[[unitvar]])
       numunits <- length(estunits)
-      tabs <- lapply(estunits, crossxbyunit, unit_grpest, unit_rowest, unit_colest,
-		unit_totest, unitvar=unitvar, rowvar=rowvar, colvar=colvar,
-		estnm=estnmd, psenm=psenm, allin1=allin1, char.width=char.width,
-		estnull=estnull, psenull=psenull, estround=estround, pseround=pseround,
-		rowgrp=rowgrp, rowgrpnm=rowgrpnm, title.rnames=title.rnames,
-		numunits=numunits, savedata=savedata, addtitle=addtitle,
-		returntitle=returntitle, outfn.estpse=outfn.estpse,
-		title.estpse=title.estpse, title.est=title.est, title.pse=title.pse,
-		title.ref=title.ref, outfolder=outfolder, outfn.date=outfn.date,
-		overwrite=overwrite, esttype=esttype, phototype=phototype,
-		rnames=rnames, title.colvar=title.colvar, title.unitvar=title.unitvar)
+      tabs <- lapply(estunits, crossxbyunit, 
+                     unit_grpest, unit_rowest, unit_colest,
+		                 unit_totest, 
+		                 unitvar = unitvar, 
+		                 rowvar = rowvar, colvar = colvar,
+		                 estnm = estnmd, psenm = psenm, 
+		                 allin1 = allin1, char.width = char.width,
+		                 estnull = estnull, psenull = psenull, 
+		                 estround = estround, pseround = pseround,
+		                 rowgrp = rowgrp, rowgrpnm = rowgrpnm, 
+		                 title.rnames = title.rnames,
+		                 numunits = numunits, 
+		                 savedata = savedata, addtitle = addtitle,
+		                 returntitle = returntitle, 
+		                 outfn.estpse = outfn.estpse,
+		                 title.estpse = title.estpse, 
+		                 title.est = title.est, title.pse = title.pse,
+		                 title.ref = title.ref, 
+		                 outfolder = outfolder, outfn.date = outfn.date,
+		                 overwrite = overwrite, 
+		                 esttype = esttype, phototype = phototype,
+		                 rnames = rnames, 
+		                 title.colvar = title.colvar, title.unitvar = title.unitvar)
       names(tabs) <- estunits
       est2return <- rbindlist(lapply(tabs, `[[`, 1), use.names=TRUE, fill=TRUE)
       if (!allin1) {
@@ -595,7 +627,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
         suppressWarnings(unit_totest[, (unitvars) := tstrsplit(get(unitvar), "-", fixed=TRUE)])
         unit_totest[, (unitvar) := NULL]
         setcolorder(unit_totest, c(unitvars,
-		names(unit_totest)[!names(unit_totest) %in% unitvars]))
+		    names(unit_totest)[!names(unit_totest) %in% unitvars]))
       }
       rawdat$unit_totest <- setDF(unit_totest)
       rawdat.tabs <- c(rawdat.tabs, "unit_totest")
@@ -613,7 +645,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
           suppressWarnings(unit_rowest[, (unitvars) := tstrsplit(get(unitvar), "-", fixed=TRUE)])
           unit_rowest[, (unitvar) := NULL]
           setcolorder(unit_rowest, c(unitvars,
-			names(unit_rowest)[!names(unit_rowest) %in% unitvars]))
+			    names(unit_rowest)[!names(unit_rowest) %in% unitvars]))
         }
 
         ## Set order of table
@@ -637,7 +669,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
           suppressWarnings(unit_colest[, (unitvars) := tstrsplit(get(unitvar), "-", fixed=TRUE)])
           unit_colest[, (unitvar) := NULL]
           setcolorder(unit_colest, c(unitvars,
-			names(unit_colest)[!names(unit_colest) %in% unitvars]))
+			    names(unit_colest)[!names(unit_colest) %in% unitvars]))
         }
         ## Set order of table
         setorderv(unit_colest, c(unitvars, colvar))
@@ -663,7 +695,7 @@ est.outtabs <- function(esttype, phototype="PCT", photoratio=FALSE, sumunits=FAL
           suppressWarnings(unit_grpest[, (unitvars) := tstrsplit(get(unitvar), "-", fixed=TRUE)])
           unit_grpest[, (unitvar) := NULL]
           setcolorder(unit_grpest, c(unitvars,
-			names(unit_grpest)[!names(unit_grpest) %in% unitvars]))
+			    names(unit_grpest)[!names(unit_grpest) %in% unitvars]))
         }
         ## Set order of table
         setorderv(unit_grpest, c(unitvars, rowvar, colvar))
