@@ -49,6 +49,9 @@
 #' 'VOLCFNET').
 #' @param estvar.filter String. A tree-level filter for estvar. Must be R
 #' syntax (e.g., 'STATUSCD == 1').
+#' @param estvar.derive List. A derivation of a tree variable to estimate.
+#' Must be a named list with one element (e.g., 
+#' list(SDI='SUM(POWER(DIA/10,1.605) * TPA_UNADJ)'). Set estvar = NULL.
 #' @param estseed String. Use seedling data only or add to tree data. Seedling
 #' estimates are only for counts (estvar='TPA_UNADJ')-('none', 'only', 'add').
 #' @param woodland String. If woodland = 'Y', include woodland tree species  
@@ -85,7 +88,6 @@
 #' @param title_opts List. See help(title_options()) for a list of options.
 #' @param savedata_opts List. See help(savedata_options()) for a list
 #' of options. Only used when savedata = TRUE.  
-#' @param gui Logical. If gui, user is prompted for parameters.
 #' @param modelselect_bydomain Logical. If TRUE, modelselection will occur at 
 #' the domain level as specified by rowvar and/or colvar and not at the level of
 #' the entire sample.
@@ -177,25 +179,6 @@
 #' interested in estimates for all lands or nonforest lands in the
 #' All-Condition-Inventory.
 #' 
-#' sumunits:\cr An estimation unit is a population, or area of interest, with
-#' known area and number of plots. Individual counties or combined
-#' Super-counties are common estimation units for FIA. An estimation unit may
-#' also be a subpopulation of a larger population (e.g., Counties within a
-#' State). Subpopulations are mutually exclusive and independent within a
-#' population, therefore estimated totals and variances are additive. For
-#' example, State-level estimates are generated by summing estimates from all
-#' subpopulations within the State (Bechtold and Patterson. 2005. Chapter 2).
-#' Each plot must be assigned to only one estimation unit.
-#' 
-#' stratcombine:\cr If MAmethod='PS', and stratcombine=TRUE, and less than 2
-#' plots in any one estimation unit, all estimation units with 10 or less plots
-#' are combined. The current method for combining is to group the estimation
-#' unit with less than 10 plots with the estimation unit following in
-#' consecutive order (numeric or alphabetical), restrained by survey unit
-#' (UNITCD) if included in dataset, and continuing until the number of plots
-#' equals 10. If there are no estimation units following in order, it is
-#' combined with the estimation unit previous in order.
-#' 
 #' autoxreduce:\cr If MAmethod='GREG', and autoxreduce=TRUE, and there is an
 #' error because of multicolinearity, a variable reduction method is applied to
 #' remove correlated variables. The method used is based on the
@@ -263,21 +246,13 @@
 #'           estvar.filter = "STATUSCD == 1")
 #'           
 #' str(mod1)
-#'           
-#' # Use GREG Elastic Net Estimator to Estimate basal area of live trees in our
-#' # population
-#' mod2 <- modMAtree(MApopdat = MApopdat,
-#'           MAmethod = "gregEN",
-#'           estvar = "BA",
-#'           estvar.filter = "STATUSCD == 1")
-#'           
-#' str(mod2)
 #' }
 #' @export modMAtree
 modMAtree <- function(MApopdat, 
                       MAmethod, 
                       estvar, 
                       estvar.filter = NULL, 
+                      estvar.derive = NULL,
                       estseed = "none",
                       woodland = "Y",
                       landarea = "FOREST", 
@@ -293,7 +268,6 @@ modMAtree <- function(MApopdat,
                       table_opts = NULL, 
                       title_opts = NULL, 
                       savedata_opts = NULL, 
-                      gui = FALSE, 
                       modelselect_bydomain = FALSE,
                       ...){
 
@@ -302,10 +276,7 @@ modMAtree <- function(MApopdat,
   ## Generates model-assisted estimates by domain (and estimation unit)
   ##################################################################################
 
-  ## CHECK GUI - IF NO ARGUMENTS SPECIFIED, ASSUME GUI=TRUE
-  if (nargs() == 0 && is.null(MApopdat)) {
-    gui <- TRUE
-  } 
+  gui <- FALSE
   
   ## If gui.. set variables to NULL
   if (gui) { 
@@ -315,15 +286,14 @@ modMAtree <- function(MApopdat,
   }
   
   ## Set parameters
-  minplotnum <- 10
-  esttype="TREE"
-  parameters <- FALSE
-  returnlst <- list()
+  esttype <- "TREE"
+  popType <- "VOL"
+  rawdata <- TRUE 
   sumunits <- FALSE
+  returnlst <- list()
   
   ## Set global variables
-  ONEUNIT=n.total=n.strata=strwt=TOTAL <- NULL
-  rawdata <- TRUE 
+  ONEUNIT=n.total=n.strata=strwt=TOTAL=domclassify<- NULL
   
   
   ##################################################################
@@ -341,66 +311,27 @@ modMAtree <- function(MApopdat,
 
 
   ## Check parameter lists
-  pcheck.params(input.params, table_opts=table_opts, title_opts=title_opts, 
-                savedata_opts=savedata_opts)
+  pcheck.params(input.params = input.params,
+                title_opts = title_opts, 
+                table_opts = table_opts, 
+                savedata_opts = savedata_opts)
   
-  ## Set savedata defaults
-  savedata_defaults_list <- formals(savedata_options)[-length(formals(savedata_options))]
+  ## Check parameter option lists
+  optslst <- pcheck.opts(optionlst = list(
+    title_opts = title_opts,
+    table_opts = table_opts,
+    savedata_opts = savedata_opts)) 
+  title_opts <- optslst$title_opts  
+  table_opts <- optslst$table_opts  
+  savedata_opts <- optslst$savedata_opts  
   
-  for (i in 1:length(savedata_defaults_list)) {
-    assign(names(savedata_defaults_list)[[i]], savedata_defaults_list[[i]])
+  for (i in 1:length(title_opts)) {
+    assign(names(title_opts)[[i]], title_opts[[i]])
+  }
+  for (i in 1:length(table_opts)) {
+    assign(names(table_opts)[[i]], table_opts[[i]])
   }
   
-  ## Set user-supplied savedata values
-  if (length(savedata_opts) > 0) {
-    if (!savedata) {
-      message("savedata=FALSE with savedata parameters... no data are saved")
-    }
-    for (i in 1:length(savedata_opts)) {
-      if (names(savedata_opts)[[i]] %in% names(savedata_defaults_list)) {
-        assign(names(savedata_opts)[[i]], savedata_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(savedata_opts)[[i]]))
-      }
-    }
-  }
-  
-  ## Set table defaults
-  table_defaults_list <- formals(table_options)[-length(formals(table_options))]
-  
-  for (i in 1:length(table_defaults_list)) {
-    assign(names(table_defaults_list)[[i]], table_defaults_list[[i]])
-  }
-  
-  ## Set user-supplied table values
-  if (length(table_opts) > 0) {
-    for (i in 1:length(table_opts)) {
-      if (names(table_opts)[[i]] %in% names(table_defaults_list)) {
-        assign(names(table_opts)[[i]], table_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(table_opts)[[i]]))
-      }
-    }
-  }
-  
-  ## Set title defaults
-  title_defaults_list <- formals(title_options)[-length(formals(title_options))]
-  
-  for (i in 1:length(title_defaults_list)) {
-    assign(names(title_defaults_list)[[i]], title_defaults_list[[i]])
-  }
-  
-  ## Set user-supplied title values
-  if (length(title_opts) > 0) {
-    for (i in 1:length(title_opts)) {
-      if (names(title_opts)[[i]] %in% names(title_defaults_list)) {
-        assign(names(title_opts)[[i]], title_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(title_opts)[[i]]))
-      }
-    }
-  }
-
   
   ##################################################################
   ## CHECK PARAMETER INPUTS
@@ -415,29 +346,29 @@ modMAtree <- function(MApopdat,
     predselectlst <- list()
   }
 
-  list.items <- c("condx", "pltcondx", "cuniqueid", "condid", 
-		"ACI.filter", "unitarea", "unitvar", "unitlut", "npixels",
-		"npixelvar", "plotsampcnt", "condsampcnt")
-    #if (MAmethod == "PS") {
-    #  list.items <- c(list.items, "strvar")
-    #}
-    #if (MAmethod == "greg") {
-    #  list.items <- c(list.items, "prednames")
-    #}
+  ###################################################################################
+  ## Check data and generate population information 
+  ###################################################################################
+  list.items <- c("pltcondx", "cuniqueid", "condid",
+                  "treex", "tuniqueid",
+                  "unitarea", "unitvar", "unitlut", "npixels",
+		              "npixelvar", "plotsampcnt", "condsampcnt")
+
   MApopdat <- pcheck.object(MApopdat, "MApopdat", list.items=list.items)
-  	
   if (is.null(MApopdat)) return(NULL)	
-  condx <- MApopdat$condx
+  pltidsadj <- MApopdat$pltidsadj
   pltcondx <- MApopdat$pltcondx
+  cuniqueid <- MApopdat$cuniqueid
+  pltassgnid <- MApopdat$pltassgnid
+  condid <- MApopdat$condid
   treex <- MApopdat$treex
   seedx <- MApopdat$seedx
   if (is.null(treex) && is.null(seedx)) {
     stop("must include tree data for tree estimates")
   }
-  cuniqueid <- MApopdat$cuniqueid
-  condid <- MApopdat$condid
   tuniqueid <- MApopdat$tuniqueid
-  ACI.filter <- MApopdat$ACI.filter
+  ACI <- MApopdat$ACI
+  pltassgnx <- MApopdat$pltassgnx
   unitarea <- MApopdat$unitarea
   areavar <- MApopdat$areavar
   areaunits <- MApopdat$areaunits
@@ -451,14 +382,19 @@ modMAtree <- function(MApopdat,
   condsampcnt <- MApopdat$condsampcnt
   states <- MApopdat$states
   invyrs <- MApopdat$invyrs
-  stratcombinelut <- MApopdat$stratcombinelut
   predfac <- MApopdat$predfac
-  strvar <- MApopdat$strvar
   adj <- MApopdat$adj
+  popdatindb <- MApopdat$popdatindb
   pop_fmt <- MApopdat$pop_fmt
   pop_dsn <- MApopdat$pop_dsn
- 
- 
+  pop_schema <- MApopdat$pop_schema
+  popconn <- MApopdat$popconn
+  dbqueries <- MApopdat$dbqueries
+  dbqueriesWITH <- MApopdat$dbqueriesWITH
+  adjcase <- MApopdat$adjcase
+  pltidsid <- MApopdat$pjoinid
+  pltassgnid <- MApopdat$pltassgnid
+  
   if (MAmethod %in% c("greg", "gregEN", "ratio")) {
     if (is.null(prednames)) {
       prednames <- MApopdat$prednames
@@ -475,7 +411,26 @@ modMAtree <- function(MApopdat,
       }
     }
   } 
+  
+  if (popdatindb) {
+    if (is.null(popconn) || !DBI::dbIsValid(popconn)) {
+      if (!is.null(pop_dsn)) {
+        if (pop_fmt == "sqlite") {
+          popconn <- DBtestSQLite(pop_dsn, dbconnopen = TRUE)
+        }
+      } else {
+        stop("invalid database connection")
+      }
+    }
+    #pltcondx <- dbqueries$pltcondx
+    pltcondxWITHqry <- dbqueriesWITH$pltcondxWITH
+    pltcondxadjWITHqry <- dbqueriesWITH$pltcondxadjWITH
+  } else {
+    pltcondxWITHqry <- NULL
+    pltcondxWITHqry=pltcondxadjWITHqry <- NULL
+  }
 
+  
   ########################################
   ## Check area units
   ########################################
@@ -492,70 +447,97 @@ modMAtree <- function(MApopdat,
   ###################################################################################
   ## Check parameters and apply plot and condition filters
   ###################################################################################
-  estdat <- check.estdata(esttype=esttype, pop_fmt=pop_fmt, pop_dsn=pop_dsn,
-        pltcondf=pltcondx, cuniqueid=cuniqueid, condid=condid,
-        treex=treex, seedx=seedx, estseed=estseed, woodland=woodland,
-        sumunits=sumunits, totals=totals, landarea=landarea, 
-				ACI.filter=ACI.filter, pcfilter=pcfilter, 
-				allin1=allin1, estround=estround, pseround=pseround, 
-				divideby=divideby, addtitle=addtitle, returntitle=returntitle, 
-        rawdata=rawdata, rawonly=rawonly, savedata=savedata, 
-        outfolder=outfolder, overwrite_dsn=overwrite_dsn, 
-        overwrite_layer=overwrite_layer, outfn.pre=outfn.pre, 
-        outfn.date=outfn.date, append_layer=append_layer, 
-        raw_fmt=raw_fmt, raw_dsn=raw_dsn, gui=gui)
+  estdat <- 
+    check.estdata(esttype = esttype,
+                  popType = popType,
+                  popdatindb = popdatindb,
+                  popconn = popconn, pop_schema = pop_schema,
+                  pltcondx = pltcondx,
+                  totals = totals,
+                  pop_fmt=pop_fmt, pop_dsn=pop_dsn,
+                  landarea = landarea,
+                  ACI = ACI,
+                  pcfilter = pcfilter,
+                  allin1 = allin1, divideby = divideby,
+                  estround = estround, pseround = pseround,
+                  returntitle = returntitle,
+                  rawonly = rawonly,
+                  savedata = savedata,
+                  savedata_opts = savedata_opts, 
+                  gui = gui)
   if (is.null(estdat)) return(NULL)
-  pltcondf <- estdat$pltcondf
-  cuniqueid <- estdat$cuniqueid
-  treef <- estdat$treef
-  seedf <- estdat$seedf
-  tuniqueid <- estdat$tuniqueid
-  estseed <- estdat$estseed
-  woodland <- estdat$woodland
-  sumunits <- estdat$sumunits
+  esttype <- estdat$esttype
+  totals <- estdat$totals
   landarea <- estdat$landarea
   allin1 <- estdat$allin1
+  divideby <- estdat$divideby
   estround <- estdat$estround
   pseround <- estdat$pseround
-  divideby <- estdat$divideby
   addtitle <- estdat$addtitle
   returntitle <- estdat$returntitle
-  rawdata <- estdat$rawdata
   rawonly <- estdat$rawonly
   savedata <- estdat$savedata
   outfolder <- estdat$outfolder
   overwrite_layer <- estdat$overwrite_layer
+  outfn.pre <- estdat$outfn.pre
+  outfn.date <- estdat$outfn.date
+  append_layer = estdat$append_layer
+  rawfolder <- estdat$rawfolder
   raw_fmt <- estdat$raw_fmt
   raw_dsn <- estdat$raw_dsn
-  rawfolder <- estdat$rawfolder
-  conn <- estdat$conn
-
-  if ("STATECD" %in% names(pltcondf)) {
-    states <- pcheck.states(sort(unique(pltcondf$STATECD)))
-  }
-  if ("INVYR" %in% names(pltcondf)) {
-    invyr <- sort(unique(pltcondf$INVYR))
-  }
-
+  pcwhereqry <- estdat$where.qry
+  SCHEMA. <- estdat$SCHEMA.
+  pltcondflds <- estdat$pltcondflds
+  
+  
   ###################################################################################
-  ### GET ROW AND COLUMN INFO FROM condf
+  ## Check parameter inputs and tree filters
   ###################################################################################
-  rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, 
-          treef=treef, seedf=seedf, 
-          condf=pltcondf, cuniqueid=cuniqueid, 
-          tuniqueid=tuniqueid, estseed=estseed,
-          rowvar=rowvar, colvar=colvar, 
-          row.FIAname=row.FIAname, col.FIAname=col.FIAname, 
-          row.orderby=row.orderby, col.orderby=col.orderby, 
-          row.add0=row.add0, col.add0=col.add0, 
-          title.rowvar=title.rowvar, title.colvar=title.colvar, 
-          rowlut=rowlut, collut=collut, rowgrp=rowgrp, 
-          rowgrpnm=rowgrpnm, rowgrpord=rowgrpord, 
-					landarea=landarea, states=states, 
-					cvars2keep="COND_STATUS_CD") 
-  treef <- rowcolinfo$treef
-  seedf <- rowcolinfo$seedf
-  condf <- rowcolinfo$condf
+  estdatVOL <- 
+    check.estdataVOL(esttype = esttype,
+                     popdatindb = popdatindb,
+                     popconn = popconn,
+                     cuniqueid = cuniqueid, condid = condid,
+                     treex = treex, seedx = seedx,
+                     tuniqueid = tuniqueid,
+                     estseed = estseed,
+                     woodland = woodland,
+                     gui = gui)
+  treex <- estdatVOL$treex
+  treeflds <- estdatVOL$treeflds
+  tuniqueid <- estdatVOL$tuniqueid
+  estseed <- estdatVOL$estseed
+  woodland <- estdatVOL$woodland
+  
+  seedx <- estdatVOL$seedx
+  seedflds <- estdatVOL$seedflds
+
+  
+  ###################################################################################
+  ### Check row and column data
+  ###################################################################################
+  rowcolinfo <- 
+    check.rowcol(esttype = esttype, 
+                 popType = popType,
+                 popdatindb = popdatindb,
+                 popconn = popconn, SCHEMA. = SCHEMA.,
+                 pltcondx = pltcondx,
+                 pltcondflds = pltcondflds,
+                 withqry = pltcondxWITHqry,
+                 estseed = estseed,
+                 treex = treex, treeflds = treeflds,
+                 seedx = seedx, seedflds = seedflds,
+                 cuniqueid = cuniqueid, condid = condid,
+                 rowvar = rowvar, colvar = colvar, 
+                 row.FIAname = row.FIAname, col.FIAname = col.FIAname, 
+                 row.orderby = row.orderby, col.orderby = col.orderby,
+                 row.classify = row.classify, col.classify = col.classify,
+                 row.add0 = row.add0, col.add0 = col.add0, 
+                 title.rowvar = title.rowvar, title.colvar = title.colvar, 
+                 rowlut = rowlut, collut = collut, 
+                 rowgrp = rowgrp, rowgrpnm = rowgrpnm, 
+                 rowgrpord = rowgrpord, title.rowgrp = NULL, 
+                 gui = gui)
   uniquerow <- rowcolinfo$uniquerow
   uniquecol <- rowcolinfo$uniquecol
   domainlst <- rowcolinfo$domainlst
@@ -571,76 +553,115 @@ modMAtree <- function(MApopdat,
   title.colvar <- rowcolinfo$title.colvar
   rowgrpnm <- rowcolinfo$rowgrpnm
   title.rowgrp <- rowcolinfo$title.rowgrp
+  grpvar <- rowcolinfo$grpvar
   bytdom <- rowcolinfo$bytdom
+  bypcdom <- rowcolinfo$bypcdom
   tdomvar <- rowcolinfo$tdomvar
   tdomvar2 <- rowcolinfo$tdomvar2
-  grpvar <- rowcolinfo$grpvar
-  rm(rowcolinfo)  
+  classifyrow <- rowcolinfo$classifyrow
+  classifycol <- rowcolinfo$classifycol
+  #rm(rowcolinfo)
   
+  ## if classified columns, create domclassify list for summarizing tree data
+  if (any(!is.null(classifyrow), !is.null(classifycol))) {
+    domclassify <- list()
+    if (!is.null(classifyrow)) {
+      domclassify[[rowvar]] <- classifyrow$row.classify
+    }
+    if (!is.null(classifycol)) {
+      domclassify[[colvar]] <- classifycol$col.classify
+    }
+  }
+
   #################################################################################
   ### GET ESTIMATION DATA FROM TREE TABLE
   #################################################################################
   adjtree <- ifelse(adj %in% c("samp", "plot"), TRUE, FALSE)
-  treedat <- check.tree(gui=gui, treef=treef, seedf=seedf, estseed=estseed, 
-        bycond=TRUE, condf=condf, bytdom=bytdom, 
-        tuniqueid=tuniqueid, cuniqueid=cuniqueid, 
-        esttype=esttype, estvarn=estvar, estvarn.filter=estvar.filter, 
-        esttotn=TRUE, tdomvar=tdomvar, tdomvar2=tdomvar2, 
-        adjtree=adjtree, metric=metric, woodland=woodland)
-  if (is.null(treedat)) return(NULL)
+  if (popdatindb) {
+    pltidsWITHqry <- dbqueriesWITH$pltcondxadjWITH
+  } else {
+    pltidsWITHqry <- NULL
+  }
+  treedat <- 
+    check.tree(treex = treex, 
+               seedx = seedx, 
+               estseed = estseed,
+               bycond = TRUE, 
+               condx = pltcondx, 
+               tuniqueid = tuniqueid, cuniqueid = cuniqueid, 
+               esttype = esttype, 
+               estvarn = estvar, 
+               estvarn.filter = estvar.filter, 
+               estvarn.derive = estvar.derive,
+               esttotn = TRUE, 
+               bydomainlst = c(domainlst, "TOTAL"),
+               tdomvar = tdomvar, tdomvar2 = tdomvar2,
+               adjtree = adjtree, 
+               adjvar = "tadjfac",
+               metric = metric, 
+               woodland = woodland,
+               ACI = ACI,
+               domclassify = domclassify,
+               dbconn = popconn, schema = pop_schema,
+               pltidsWITHqry = pltidsWITHqry,
+               pcwhereqry = pcwhereqry,
+               pltidsid = pltidsid,
+               bytdom = bytdom,
+               gui = gui)
+  if (is.null(treedat)) stop(NULL) 
   tdomdat <- treedat$tdomdat
-  
-  ## Merge tdomdat with condx
-  xchk <- check.matchclass(condx, tdomdat, c(cuniqueid, condid))
-  condx <- xchk$tab1
-  tdomdat <- xchk$tab2
-  tdomdat <- merge(condx, tdomdat, by=c(cuniqueid, condid), all.x=TRUE)
-  
   estvar <- treedat$estvar
   estvar.name <- treedat$estvar.name
   estvar.filter <- treedat$estvar.filter
   tdomvarlst <- treedat$tdomvarlst
   estunits <- treedat$estunits
-
-  ## Check for matching levels in x and xunique
-  if (!is.null(uniquerow)) {
-    chklevels <- checklevels(x = tdomdat, 
-	                           uniquex = uniquerow,
-						                 xvar = rowvar) 
-	  tdomdat <- chklevels$x
-    uniquerow <- chklevels$uniquex	
-  }
-  if (!is.null(uniquecol)) {
-    chklevels <- checklevels(x = tdomdat, 
-	                          uniquex = uniquecol,
-							             xvar = colvar) 
-	  tdomdat <- chklevels$x
-    uniquecol <- chklevels$uniquex	
-  }
- 
-  ## Generate a uniquecol for estimation units
-  if (!sumunits && colvar == "NONE") {
-    uniquecol <- data.table(unitarea[[unitvar]])
-    setnames(uniquecol, unitvar)
-    uniquecol[[unitvar]] <- factor(uniquecol[[unitvar]])
+  treeqry <- treedat$treeqry
+  classifynmlst <- treedat$classifynmlst
+  
+  ## If classified rowvar or colvar, get class names
+  if (!is.null(classifynmlst)) {
+    if (!is.null(classifynmlst[[rowvar]])) {
+      rowvar <- classifynmlst[[rowvar]]
+    }
+    if (!is.null(classifynmlst[[colvar]])) {
+      colvar <- classifynmlst[[colvar]]
+    }
+    if (!is.null(grpvar)) {
+      grpvar <- c(rowvar, colvar)
+    }
   }
 
   #################################################################################
   ### GET TITLES FOR OUTPUT TABLES
   #################################################################################
-  alltitlelst <- check.titles(dat=tdomdat, esttype=esttype, 
-          estseed=estseed, woodland=woodland,
-          sumunits=sumunits, title.main=title.main, title.ref=title.ref, 
-          title.rowvar=title.rowvar, title.rowgrp=title.rowgrp, 
-          title.colvar=title.colvar, title.unitvar=title.unitvar, 
-          title.filter=title.filter, title.unitsn=estunits, 
-          title.estvarn=title.estvar, 
-					unitvar=unitvar, rowvar=rowvar, colvar=colvar, 
-					estvarn=estvar, estvarn.filter=estvar.filter, 
-					addtitle=addtitle, returntitle=returntitle, 
-					rawdata=rawdata, states=states, invyrs=invyrs, 
-					landarea=landarea, pcfilter=pcfilter, allin1=allin1, 
-					divideby=divideby, outfn.pre=outfn.pre)
+  alltitlelst <- 
+    check.titles(dat = tdomdat,
+                 esttype = esttype, 
+                 estseed = estseed,
+                 woodland = woodland,
+                 sumunits = sumunits,
+                 title.main = title.main,
+                 title.ref = title.ref, 
+                 title.rowvar = title.rowvar,
+                 title.rowgrp = title.rowgrp, 
+                 title.colvar = title.colvar,
+                 title.unitvar = title.unitvar, 
+                 title.filter = title.filter,
+                 title.unitsn = estunits, 
+                 title.estvarn = title.estvar, 
+                 unitvar = unitvar,
+                 rowvar = rowvar, colvar = colvar, 
+                 estvarn = estvar,
+                 estvarn.filter = estvar.filter, 
+                 addtitle = addtitle,
+                 returntitle = returntitle, 
+                 rawdata = rawdata,
+                 states = states, invyrs = invyrs, 
+                 landarea = landarea,
+                 pcfilter =pcfilter,
+                 allin1 = allin1, 
+                 divideby = divideby,
+                 outfn.pre = outfn.pre)
   title.unitvar <- alltitlelst$title.unitvar
   title.est <- alltitlelst$title.est
   title.pse <- alltitlelst$title.pse
@@ -655,274 +676,105 @@ modMAtree <- function(MApopdat,
   ## Append name of package and method to outfile name
   outfn.estpse <- paste0(outfn.estpse, "_modMA_mase", "_", MAmethod) 
 
+ 
   #################################################################################
   ## GENERATE ESTIMATES
   #################################################################################
-  unit_totest=unit_rowest=unit_colest=unit_grpest=rowunit=totunit <- NULL
-  addtotal <- ifelse(((rowvar == "TOTAL" || length(unique(tdomdat[[rowvar]])) > 1) ||
-		(!is.null(tdomvarlst) && length(tdomvarlst) > 1)), TRUE, FALSE)
-  response <- estvar.name
-  estunits <- sort(unique(tdomdat[[unitvar]]))
-
-  masemethod <- ifelse(MAmethod == "PS", "postStrat", 
-	ifelse(MAmethod == "greg", "greg", 
-	ifelse(MAmethod == "gregEN", "gregElasticNet", 
-	ifelse(MAmethod == "ratio", "ratioEstimator", "horvitzThompson"))))
-  message("generating estimates using mase::", masemethod, " function...\n")
+  estdat <- 
+    getMAestimates(esttype = esttype,
+                   domdatn = tdomdat,
+                   uniqueid = pltassgnid,
+                   estvarn.name = estvar.name,
+                   rowvar = rowvar, colvar = colvar, 
+                   grpvar = grpvar,
+                   MAmethod = MAmethod,
+                   modelselect = modelselect,
+                   prednames = prednames,
+                   FIA = FIA,
+                   bootstrap = bootstrap,
+                   pltassgnx = pltassgnx,
+                   unitarea = unitarea,
+                   unitvar = unitvar,
+                   areavar = areavar,
+                   unitlut = unitlut,
+                   npixels = npixels,
+                   totals = totals,
+                   uniquerow = uniquerow,
+                   uniquecol = uniquecol,
+                   row.orderby = row.orderby,
+                   col.orderby = col.orderby,
+                   row.add0 = row.add0,
+                   col.add0 = col.add0,
+                   row.NAname = row.NAname,
+                   col.NAname = col.NAname)
   
-  predselect.overall <- NULL
-  if (MAmethod == "greg" && modelselect == T) {
-    
-    # want to do variable selection on plot level data...
-    pltlvl <- tdomdat[ , lapply(.SD, sum, na.rm = TRUE), 
-                       by=c(unitvar, cuniqueid, "TOTAL", strvar, prednames),
-                       .SDcols=response]
-    
-    y <- pltlvl[[response]]
-    xsample <- pltlvl[ , prednames, with = F, drop = F]
-
-    # need to go means -> totals -> summed totals
-    xpop <- unitlut[ , c(unitvar, prednames), with = F, drop = F]
-    if (is.factor(xpop[[unitvar]])) {
-      npix_temp <- npixels[ ,(unitvar) := as.factor(get(unitvar))]
-    } else {
-      npix_temp <- npixels
-    }
-    xpop_npix <- merge(xpop, npix_temp, by = unitvar, all.x = TRUE)
-    # multiply unitvar level population means by corresponding npixel values to get population level totals
-    xpop_npix[ ,2:ncol(xpop)] <- lapply(xpop_npix[ ,2:ncol(xpop)], function(x) xpop_npix[["npixels"]] * x)
-    # sum those values
-    xpop_totals <- colSums(xpop_npix[ ,2:ncol(xpop)])
-    # format xpop for mase input
-    xpop_totals <- data.frame(as.list(xpop_totals))
-    
-    N <- sum(npixels[["npixels"]])
-    xpop_means <- xpop_totals/N
-    
-    # since we want to do modelselection + get the coefficients, just use MAest.greg
-    coefs_select <- MAest.greg(y = y,
-                               N = N,
-                               x_sample = setDF(xsample),
-                               x_pop = xpop_means,
-                               modelselect = TRUE)
-  
-    
-    predselect.overall <- coefs_select$predselect
-  
-    prednames <- names(predselect.overall[ ,(!is.na(predselect.overall))[1,], with = F])
-    message(paste0("Predictors ", "[", paste0(prednames, collapse = ", "), "]", " were chosen in model selection.\n"))
-  
-      
-  }
-  
-  if (!MAmethod %in% c("HT", "PS")) {
-    message("using the following predictors...", toString(prednames))
-  }
-  getweights <- ifelse(MAmethod %in% c("greg", "PS", "HT"), TRUE, FALSE) 
-  getweights <- FALSE
-  
-  if(bootstrap) {
-    if(MAmethod %in% c('greg', 'gregEN', 'ratio')) {
-      var_method <- "bootstrapSRS"
-    }
-  } else {
-    if(MAmethod %in% c('greg', 'gregEN', 'ratio')) {
-      var_method <- "LinHTSRS"
-    }
-  }
-  
-#  if (addtotal) {
-    ## Get total estimate and merge area
-    tdomdattot <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(unitvar, cuniqueid, "TOTAL", strvar, prednames), .SDcols=response]
-    unit_totestlst <- lapply(estunits, MAest.unit, 
-                        dat=tdomdattot, cuniqueid=cuniqueid, 
-                        unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
-                        MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
-                        domain="TOTAL", response=response, npixels=npixels, 
-                        FIA=FIA, modelselect=modelselect_bydomain, getweights=getweights,
-                        var_method=var_method)
-    unit_totest <- do.call(rbind, sapply(unit_totestlst, '[', "unitest"))
-    unit_weights <- do.call(rbind, sapply(unit_totestlst, '[', "weights")) 
-    unit_weights$areaweights <- unit_weights$weights * sum(unitarea[[areavar]])
-    if (MAmethod %in% c("greg", "gregEN")) {
-      predselectlst$totest <- do.call(rbind, sapply(unit_totestlst, '[', "predselect"))
-    }
-    tabs <- check.matchclass(unitarea, unit_totest, unitvar)
-    unitarea <- tabs$tab1
-    unit_totest <- tabs$tab2
-    setkeyv(unit_totest, unitvar)
-    unit_totest <- unit_totest[unitarea, nomatch=0]
-    if (totals) {
-      unit_totest <- getpse(unit_totest, areavar=areavar, esttype=esttype)
-    } else {
-      unit_totest <- getpse(unit_totest, esttype=esttype)
-    }      
-#  }
-
-  ## Get row, column, cell estimate and merge area if row or column in cond table 
-  if (rowvar != "TOTAL") {
-    tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]),] 
-    tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(unitvar, cuniqueid, rowvar, strvar, prednames), .SDcols=response]
-    unit_rowestlst <- lapply(estunits, MAest.unit, 
-                        dat=tdomdatsum, cuniqueid=cuniqueid, 
-                        unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
-                        MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
-                        domain=rowvar, response=response, npixels=npixels, 
-                        FIA=FIA, modelselect=modelselect_bydomain, getweights=getweights,
-                        var_method=var_method)
-    unit_rowest <- do.call(rbind, sapply(unit_rowestlst, '[', "unitest"))
-    if (MAmethod %in% c("greg", "gregEN")) {
-      predselectlst$rowest <- do.call(rbind, sapply(unit_totestlst, '[', "predselect"))
-    }
-
-    if (colvar != "NONE") {
-      tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]),] 	
-      tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		by=c(unitvar, cuniqueid, colvar, strvar, prednames), .SDcols=response]
-      unit_colestlst <- lapply(estunits, MAest.unit, 
-                            dat=tdomdatsum, cuniqueid=cuniqueid, 
-                            unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
-                            MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
-                            domain=colvar, response=response, npixels=npixels, 
-                            FIA=FIA, modelselect=modelselect_bydomain, var_method=var_method)
-      unit_colest <- do.call(rbind, sapply(unit_colestlst, '[', "unitest"))
-      if (MAmethod %in% c("greg", "gregEN")) {
-        predselectlst$colest <- do.call(rbind, sapply(unit_colestlst, '[', "predselect"))
-      }
-
-      tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
-		        by=c(unitvar, cuniqueid, grpvar, strvar, prednames), .SDcols=response]
-      tdomdatsum[, grpvar := do.call(paste, c(.SD, sep="#")), .SDcols=grpvar]
-
-      unit_grpestlst <- lapply(estunits, MAest.unit, 
-                               dat=tdomdatsum, cuniqueid=cuniqueid, 
-                               unitlut=unitlut, unitvar=unitvar, esttype=esttype, 
-                               MAmethod=MAmethod, strvar=strvar, prednames=prednames, 
-                               domain="grpvar", response=response, npixels=npixels, 
-                               FIA=FIA, modelselect=modelselect_bydomain, var_method=var_method)
-      unit_grpest <- do.call(rbind, sapply(unit_grpestlst, '[', "unitest"))
-      if (MAmethod %in% c("greg", "gregEN")) {
-        predselectlst$grpest <- do.call(rbind, sapply(unit_grpestlst, '[', "predselect"))
-      }
-      if (any(unit_grpest$grpvar == "NA#NA")) {
-        unit_grpest <- unit_grpest[unit_grpest$grpvar != "NA#NA", ]
-      }
-      unit_grpest[, c(rowvar, colvar) := tstrsplit(grpvar, "#", fixed=TRUE)]
-    }
-  }
-
-  ###############################################################################
-  ## Check add0 and Add area
-  ###############################################################################
-  if (!sumunits && nrow(unitarea) > 1) col.add0 <- TRUE
-  if (!is.null(unit_rowest)) {
-    unit_rowest <- add0unit(x=unit_rowest, xvar=rowvar, uniquex=uniquerow, 
-		unitvar=unitvar, xvar.add0=row.add0)
-    tabs <- check.matchclass(unitarea, unit_rowest, unitvar)
-    unitarea <- tabs$tab1
-    unit_rowest <- tabs$tab2
-
-    if (!is.null(row.orderby) && row.orderby != "NONE") {
-      setorderv(unit_rowest, c(row.orderby))
-    }
-    setkeyv(unit_rowest, unitvar)
-    unit_rowest <- unit_rowest[unitarea, nomatch=0]
-    if (totals) {
-      unit_rowest <- getpse(unit_rowest, areavar=areavar, esttype=esttype)
-    } else {
-      unit_rowest <- getpse(unit_rowest, esttype=esttype)
-    }
-    setkeyv(unit_rowest, c(unitvar, rowvar))
-  }
- 
-  if (!is.null(unit_colest)) {
-    unit_colest <- add0unit(x=unit_colest, xvar=colvar, uniquex=uniquecol, 
-		unitvar=unitvar, xvar.add0=col.add0)
-    tabs <- check.matchclass(unitarea, unit_colest, unitvar)
-    unitarea <- tabs$tab1
-    unit_colest <- tabs$tab2
-
-    if (!is.null(col.orderby) && col.orderby != "NONE") {
-      setorderv(unit_colest, c(col.orderby))
-    }
-    setkeyv(unit_colest, unitvar)
-    unit_colest <- unit_colest[unitarea, nomatch=0]
-    if (totals) {
-      unit_colest <- getpse(unit_colest, areavar=areavar, esttype=esttype)
-    } else {
-      unit_colest <- getpse(unit_colest, esttype=esttype)
-    }      
-    setkeyv(unit_colest, c(unitvar, colvar))
-  }
-
-  if (!is.null(unit_grpest)) {
-    unit_grpest <- add0unit(x=unit_grpest, xvar=rowvar, uniquex=uniquerow, 
-		unitvar=unitvar, xvar.add0=row.add0, xvar2=colvar, uniquex2=uniquecol,
-		xvar2.add0=col.add0)
-    tabs <- check.matchclass(unitarea, unit_grpest, unitvar)
-    unitarea <- tabs$tab1
-    unit_grpest <- tabs$tab2
-
-    if (!is.null(row.orderby) && row.orderby != "NONE") {
-      if (!is.null(col.orderby) && col.orderby != "NONE") {
-        setorderv(unit_grpest, c(row.orderby, col.orderby))
-      } else {
-        setorderv(unit_grpest, c(row.orderby))
-      }         
-    } else if (!is.null(col.orderby) && col.orderby != "NONE") {
-      setorderv(unit_grpest, c(col.orderby))
-    }         
-    setkeyv(unit_grpest, unitvar)
-    unit_grpest <- unit_grpest[unitarea, nomatch=0]
-    if (totals) {
-      unit_grpest <- getpse(unit_grpest, areavar=areavar, esttype=esttype)
-    } else {
-      unit_grpest <- getpse(unit_grpest, esttype=esttype)
-    }      
-    setkeyv(unit_grpest, c(unitvar, rowvar, colvar))
-  }
+  if (is.null(estdat)) stop()
+  unit_totest <- estdat$unit_totest
+  unit_rowest <- estdat$unit_rowest
+  unit_colest <- estdat$unit_colest
+  unit_grpest <- estdat$unit_grpest
+  predselectlst <- estdat$predselectlst
+  predselect.overall <- estdat$predselect.overall
+  unit_weights <- estdat$unit_weights
  
+  
   ###############################################################################
   ## GENERATE OUTPUT TABLES
   ###############################################################################
   message("getting output...")
   estnm <- "est"
-  tabs <- est.outtabs(esttype=esttype, sumunits=sumunits, areavar=areavar, 
-                unitvar=unitvar, unitvars=unitvars, unit_totest=unit_totest, 
-                unit_rowest=unit_rowest, unit_colest=unit_colest, unit_grpest=unit_grpest, 
-                rowvar=rowvarnm, colvar=colvarnm, uniquerow=uniquerow, uniquecol=uniquecol, 
-                rowgrp=rowgrp, rowgrpnm=rowgrpnm, rowunit=rowunit, totunit=totunit, 
-                allin1=allin1, savedata=savedata, addtitle=addtitle, 
-                title.ref=title.ref, title.colvar=title.colvar, 
-                title.rowvar=title.rowvar, title.rowgrp=title.rowgrp, 
-                title.unitvar=title.unitvar, title.estpse=title.estpse, 
-                title.est=title.est, title.pse=title.pse, 
-				rawdata=rawdata, rawonly=rawonly, outfn.estpse=outfn.estpse, 
-                outfolder=outfolder, outfn.date=outfn.date, 
-                overwrite=overwrite_layer, estnm=estnm, 
-                estround=estround, pseround=pseround, divideby=divideby, 
-                returntitle=returntitle, estnull=estnull, psenull=psenull, 
-				raw.keep0=raw.keep0) 
-
+  tabs <- 
+    est.outtabs(esttype = esttype, 
+                sumunits = sumunits, areavar = areavar, 
+                unitvar = unitvar, unitvars = unitvars, 
+                unit_totest = unit_totest, 
+                unit_rowest = unit_rowest, unit_colest = unit_colest, 
+                unit_grpest = unit_grpest,
+                rowvar = rowvarnm, colvar = colvarnm, 
+                uniquerow = uniquerow, uniquecol = uniquecol,
+                rowgrp = rowgrp, rowgrpnm = rowgrpnm, 
+                allin1 = allin1, 
+                savedata = savedata, addtitle = addtitle, 
+                title.ref = title.ref, 
+                title.rowvar = title.rowvar, title.colvar = title.colvar, 
+                title.rowgrp = title.rowgrp,
+                title.unitvar = title.unitvar, title.estpse = title.estpse, 
+                title.est = title.est, title.pse = title.pse, 
+                rawdata = rawdata, rawonly = rawonly, 
+                outfn.estpse = outfn.estpse, 
+                outfolder = outfolder, outfn.date = outfn.date, 
+                overwrite = overwrite_layer, estnm = estnm, 
+                estround = estround, pseround = pseround, 
+                divideby = divideby, 
+                returntitle = returntitle, 
+                estnull = estnull, psenull = psenull, 
+                raw.keep0 = raw.keep0) 
+  
   est2return <- tabs$tabest
   pse2return <- tabs$tabpse
 
+  if (!row.add0 && any(est2return$Total == "--")) {
+    est2return <- est2return[est2return$Total != "--",]
+  }
   if (!is.null(est2return)) {
-    returnlst$est <- est2return 
+    if (!row.add0 && any(est2return$Total == "--")) {
+      est2return <- est2return[est2return$Total != "--",]
+    }
+    returnlst$est <- setDF(est2return)
   }
   if (!is.null(pse2return)) {
-    returnlst$pse <- pse2return 
+    if (!row.add0 && any(pse2return$Total == "--")) {
+      pse2return <- pse2return[pse2return$Total != "--",]
+    }
+    returnlst$pse <- setDF(pse2return) 
   }
-  if (returntitle) {
+  if(returntitle) {
     returnlst$titlelst <- alltitlelst
   }
-
+  
   if (rawdata) {
     rawdat <- tabs$rawdat
     rawdat$domdat <- setDF(tdomdat)
-    #rawdat$expcondtab <- unit_weights
     rawdat$plotweights <- unit_weights
     rawdat$estvar <- estvar.name
     rawdat$estvar.filter <- estvar.filter
@@ -973,12 +825,9 @@ modMAtree <- function(MApopdat,
     rawdat$estunits <- estunits
     returnlst$raw <- rawdat
   }
-  if ("STATECD" %in% names(pltcondf)) {
-    returnlst$statecd <- sort(unique(pltcondf$STATECD))
-  }
-  if ("INVYR" %in% names(pltcondf)) {
-    returnlst$invyr <- sort(unique(pltcondf$INVYR))
-  }
+  returnlst$statecd <- sort(pcheck.states(states, statereturn = "VALUE"))
+  returnlst$states <- states
+  returnlst$invyr <- sort(unique(unlist(invyrs)))
     
   return(returnlst)
 }
