@@ -188,122 +188,47 @@ spGetXY <- function(bnd,
   
   
   ## Check parameter lists
-  pcheck.params(input.params, savedata_opts=savedata_opts, eval_opts=eval_opts)
+  pcheck.params(input.params, 
+                savedata_opts = savedata_opts, 
+                eval_opts = eval_opts,
+                xy_opts = xy_opts)
   
+  ## Check parameter option lists
+  optslst <- pcheck.opts(optionlst = list(
+                         savedata_opts = savedata_opts,
+                         eval_opts = eval_opts, 
+                         xy_opts = xy_opts))
+  savedata_opts <- optslst$savedata_opts  
+  eval_opts <- optslst$eval_opts
+  xy_opts <- optslst$xy_opts  
 
-  ## Set eval_options defaults
-  eval_defaults_list <- formals(eval_options)[-length(formals(eval_options))]
-  for (i in 1:length(eval_defaults_list)) {
-    assign(names(eval_defaults_list)[[i]], eval_defaults_list[[i]])
+  for (i in 1:length(eval_opts)) {
+    assign(names(eval_opts)[[i]], eval_opts[[i]])
   }
-  ## Set user-supplied eval_opts values
-  if (length(eval_opts) > 0) {
-    for (i in 1:length(eval_opts)) {
-      if (names(eval_opts)[[i]] %in% names(eval_defaults_list)) {
-        assign(names(eval_opts)[[i]], eval_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(eval_opts)[[i]]))
-      }
-    }
-    ## Append eval_options defaults not specified to pass on to DBgetXY()
-    if (any(names(eval_defaults_list) %in% names(eval_opts))) {
-      eval_opts <- append(eval_opts, 
-		eval_defaults_list[!names(eval_defaults_list) %in% names(eval_opts)])
-    }
-  } else {
-    message("no evaluation timeframe specified...")
-    message("see eval and eval_opts parameters (e.g., eval='custom', eval_opts=eval_options(Cur=TRUE))\n")
-    stop()
+  for (i in 1:length(xy_opts)) {
+    assign(names(xy_opts)[[i]], xy_opts[[i]])
   }
-
-  ## Set xy_options defaults
-  xy_defaults_list <- formals(xy_options)[-length(formals(xy_options))]  
-  for (i in 1:length(xy_defaults_list)) {
-    assign(names(xy_defaults_list)[[i]], xy_defaults_list[[i]])
-  }
-  ## Set user-supplied xy_opts values
-  if (length(xy_opts) > 0) {
-    for (i in 1:length(xy_opts)) {
-      if (names(xy_opts)[[i]] %in% names(xy_defaults_list)) {
-        assign(names(xy_opts)[[i]], xy_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(xy_opts)[[i]]))
-      }
-    }
-    ## Append xy_options defaults not specified to pass on to DBgetXY()
-    if (any(names(xy_defaults_list) %in% names(xy_opts))) {
-      xy_opts <- append(xy_opts, 
-		xy_defaults_list[!names(xy_defaults_list) %in% names(xy_opts)])
-    }
-  } 
-
-  ## Set savedata defaults
-  savedata_defaults_list <- formals(savedata_options)[-length(formals(savedata_options))]
-  for (i in 1:length(savedata_defaults_list)) {
-    assign(names(savedata_defaults_list)[[i]], savedata_defaults_list[[i]])
-  } 
-  ## Set user-supplied savedata values
-  if (length(savedata_opts) > 0) {
-    if (!savedata) {
-      message("savedata=FALSE with savedata parameters... no data are saved")
-    }
-    for (i in 1:length(savedata_opts)) {
-      if (names(savedata_opts)[[i]] %in% names(savedata_defaults_list)) {
-        assign(names(savedata_opts)[[i]], savedata_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(savedata_opts)[[i]]))
-      }
-    }
+  for (i in 1:length(savedata_opts)) {
+    assign(names(savedata_opts)[[i]], savedata_opts[[i]])
   }
   
-  ## Set eval_options defaults
-  eval_defaults_list <- formals(eval_options)[-length(formals(eval_options))]
-  for (i in 1:length(eval_defaults_list)) {
-    assign(names(eval_defaults_list)[[i]], eval_defaults_list[[i]])
-  }
-  ## Set user-supplied eval_opts values
-  if (length(eval_opts) > 0) {
-    for (i in 1:length(eval_opts)) {
-      if (names(eval_opts)[[i]] %in% names(eval_defaults_list)) {
-        assign(names(eval_opts)[[i]], eval_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(eval_opts)[[i]]))
+  ## Set user-supplied dbTabs options
+  dbTables_defaults_list <- formals(dbTables)[-length(formals(dbTables))]
+  dbTabs2 <- dbTables_defaults_list
+  if (length(dbTabs) > 0) {
+    for (i in 1:length(dbTabs)) {
+      if (names(dbTabs)[[i]] %in% names(dbTables_defaults_list)) {
+        if (!is.null(dbTabs[[i]])) {
+          dbTabs2[[names(dbTabs)[[i]]]] <- dbTabs[[i]]
+        }
       }
     }
-    ## Append eval_options defaults not specified to pass on to DBgetXY()
-    if (any(names(eval_defaults_list) %in% names(eval_opts))) {
-      eval_opts <- append(eval_opts, 
-                          eval_defaults_list[!names(eval_defaults_list) %in% names(eval_opts)])
-    }
-  } else {
-    message("no evaluation timeframe specified... using all data in database...\n")
-    eval_opts$allyrs <- TRUE
-    
-    #    stop("must specify an evaluation timeframe for data extraction... \n", 
-    #	"...see eval_opts parameter, (e.g., eval_opts=eval_options(evalCur=TRUE))")
+  }
+  for (i in 1:length(dbTabs2)) {
+    assign(names(dbTabs2)[[i]], dbTabs2[[i]])
   }
   
-  ## Set xy_options defaults
-  xy_defaults_list <- formals(xy_options)[-length(formals(xy_options))]  
-  for (i in 1:length(xy_defaults_list)) {
-    assign(names(xy_defaults_list)[[i]], xy_defaults_list[[i]])
-  }
-  ## Set user-supplied xy_opts values
-  if (length(xy_opts) > 0) {
-    for (i in 1:length(xy_opts)) {
-      if (names(xy_opts)[[i]] %in% names(xy_defaults_list)) {
-        assign(names(xy_opts)[[i]], xy_opts[[i]])
-      } else {
-        stop(paste("Invalid parameter: ", names(xy_opts)[[i]]))
-      }
-    }
-    ## Append xy_options defaults not specified to pass on to DBgetXY()
-    if (any(names(xy_defaults_list) %in% names(xy_opts))) {
-      xy_opts <- append(xy_opts, 
-                        xy_defaults_list[!names(xy_defaults_list) %in% names(xy_opts)])
-    }
-  } 
- 
+  
   ##################################################################################
   ## CHECK PARAMETER INPUTS
   ##################################################################################
@@ -311,6 +236,10 @@ spGetXY <- function(bnd,
   ## Import boundary
   ########################################################
   bndx <- pcheck.spatial(layer=bnd, dsn=bnd_dsn, caption="boundary")
+  if (any(!sf::st_is_valid(bndx))) {
+    bndx <- sf::st_make_valid(bndx)
+  }
+  
  
   if (!is.null(bndx)) {
     ## bnd.filter
@@ -398,7 +327,7 @@ spGetXY <- function(bnd,
                             stbnd.att = "COUNTYFIPS", 
                             RS = RS, 
                             states = states, 
-                            clipbnd = TRUE,
+                            clipbnd = FALSE,
                             showsteps = showsteps)
     bndx <- statedat$bndx
     stbnd.att <- statedat$stbnd.att
@@ -447,6 +376,7 @@ spGetXY <- function(bnd,
 #    }
 
   } else {
+
     xydat <- DBgetXY(states = stcds,
                      xy_datsource = xy_datsource,
                      xy_dsn = xy_dsn,
@@ -471,6 +401,7 @@ spGetXY <- function(bnd,
     pjoinid <- xydat$pjoinid 
     evalInfo <- xydat$evalInfo
     pop_plot_stratum_assgn <- xydat$pop_plot_stratum_assgn
+    dbconn <- xydat$dbconn
     if (!is.null(evalInfo)) {
       states <- evalInfo$states
 
@@ -617,6 +548,10 @@ spGetXY <- function(bnd,
   returnlst$xyjoinid <- xyjoinid
   returnlst$states <- statenames
   returnlst$countyfips <- countyfips
+  
+  if (!is.null(dbconn)) {
+    returnlst$dbconn <- dbconn
+  }
 
   #if (!is.null(pop_plot_stratum_assgn)) {
   #  returnlst$pop_plot_stratum_assgn <- pop_plot_stratum_assgn
